dataset_type = 'CocoDataset'
data_root = 'data/coco/'
img_norm_cfg = dict(
    mean=[123.675, 116.28, 103.53], std=[58.395, 57.12, 57.375], to_rgb=True)
    
albu_train_transforms = [
    dict(
        type='ShiftScaleRotate',
        shift_limit=0.0725,
        scale_limit=0.125,
        rotate_limit=15,
        interpolation=1,
        p=0.4),
    dict(
        type='OneOf',
        transforms=[
            dict(
                type='RGBShift',
                r_shift_limit=5,
                g_shift_limit=5,
                b_shift_limit=5,
                p=1.0),
            dict(
                type='HueSaturationValue',
                hue_shift_limit=10,
                sat_shift_limit=15,
                val_shift_limit=10,
                p=1.0),
            dict(
                type='RandomBrightnessContrast',
                brightness_limit=0.2,
                contrast_limit=0.2,
                p=1.0
            )
        ],
        p=0.2),
    dict(
        type="HorizontalFlip",
        p=0.4
    ),
    dict(
        type="VerticalFlip",
        p=0.2
    ),
    dict(
        type="RandomRotate90",
        p=0.3
    ),
    dict(
        type='OneOf',
        transforms=[
            dict(type='Blur', blur_limit=5, p=1.0),
            dict(type='MedianBlur', blur_limit=5, p=1.0),
            dict(type='GaussNoise', var_limit=25, p=1.0)
        ],
        p=0.2),
]


train_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='LoadAnnotations', with_bbox=True, with_mask=True),
    dict(type='RandomFlip', flip_ratio=0.5),
    dict(
        type='Albu',
        transforms=albu_train_transforms,
        bbox_params=dict(
            type='BboxParams',
            format='pascal_voc',
            label_fields=['gt_labels'],
            min_visibility=0.3,
            filter_lost_elements=True),
        keymap={
            'img': 'image',
            'gt_masks': 'masks',
            'gt_bboxes': 'bboxes'
        },
        update_pad_shape=False,
        skip_img_without_anno=True),
    dict(
        type='AutoAugment',
        policies=[[{
            'type': 'Resize',
            'img_scale': [(400, 1333), (1200, 1333)],
            'multiscale_mode': 'range',
            'keep_ratio': True
        }],
                  [{
                      'type': 'Resize',
                      'img_scale': [(400, 1333), (500, 1333), (600, 1333)],
                      'multiscale_mode': 'value',
                      'keep_ratio': True
                  }, {
                      'type': 'RandomCrop',
                      'crop_type': 'absolute_range',
                      'crop_size': (384, 600),
                      'allow_negative_crop': True
                  }, {
                      'type': 'Resize',
                      'img_scale': [(400, 1333), (1200, 1333)],
                      'multiscale_mode': 'range',
                      'override': True,
                      'keep_ratio': True
                  }]]),
    dict(
        type='Normalize',
        mean=[123.675, 116.28, 103.53],
        std=[58.395, 57.12, 57.375],
        to_rgb=True),
    dict(type='Pad', size_divisor=32),
    dict(type='DefaultFormatBundle'),
    dict(type='Collect', keys=['img', 'gt_bboxes', 'gt_labels', 'gt_masks'])
]
test_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(
        type='MultiScaleFlipAug',
        img_scale=(1333, 800),
        flip=False,
        transforms=[
            dict(type='Resize', keep_ratio=True),
            dict(type='RandomFlip'),
            dict(
                type='Normalize',
                mean=[123.675, 116.28, 103.53],
                std=[58.395, 57.12, 57.375],
                to_rgb=True),
            dict(type='Pad', size_divisor=32),
            dict(type='ImageToTensor', keys=['img']),
            dict(type='Collect', keys=['img'])
        ])
]
data = dict(
    samples_per_gpu=2,
    workers_per_gpu=1,
    train=dict(
        type='CocoDataset',
        ann_file=
        '/home/nick/segmentation/mmdetection/data/train/annotations_new.json',
        img_prefix='/home/nick/segmentation/mmdetection/data/train/images',
        pipeline=train_pipeline,
        seg_prefix='/home/nick/segmentation/mmdetection/data/train/images',
        classes=
        ('beetroot-steamed-without-addition-of-salt', 'bread_wholemeal', 'jam',
         'water', 'bread', 'banana', 'soft_cheese', 'ham_raw', 'hard_cheese',
         'cottage_cheese', 'coffee', 'fruit_mixed', 'pancake', 'tea',
         'salmon_smoked', 'avocado', 'spring_onion_scallion',
         'ristretto_with_caffeine', 'ham_n_s', 'egg', 'bacon',
         'chips_french_fries', 'juice_apple', 'chicken', 'tomato', 'broccoli',
         'shrimp_prawn', 'carrot', 'chickpeas', 'french_salad_dressing',
         'pasta_hornli_ch', 'sauce_cream', 'pasta_n_s', 'tomato_sauce',
         'cheese_n_s', 'pear', 'cashew_nut', 'almonds', 'lentil_n_s',
         'mixed_vegetables', 'peanut_butter', 'apple', 'blueberries',
         'cucumber', 'yogurt', 'butter', 'mayonnaise', 'soup', 'wine_red',
         'wine_white', 'green_bean_steamed_without_addition_of_salt',
         'sausage', 'pizza_margherita_baked', 'salami_ch', 'mushroom',
         'tart_n_s', 'rice', 'white_coffee', 'sunflower_seeds',
         'bell_pepper_red_raw', 'zucchini', 'asparagus', 'tartar_sauce',
         'lye_pretzel_soft', 'cucumber_pickled_ch', 'curry_vegetarian',
         'soup_of_lentils_dahl_dhal', 'salmon',
         'salt_cake_ch_vegetables_filled', 'orange', 'pasta_noodles',
         'cream_double_cream_heavy_cream_45', 'cake_chocolate',
         'pasta_spaghetti', 'black_olives', 'parmesan', 'spaetzle',
         'salad_lambs_ear', 'salad_leaf_salad_green', 'potato',
         'white_cabbage', 'halloumi', 'beetroot_raw', 'bread_grain',
         'applesauce', 'cheese_for_raclette_ch', 'bread_white',
         'curds_natural', 'quiche', 'beef_n_s',
         'taboule_prepared_with_couscous', 'aubergine_eggplant', 'mozzarella',
         'pasta_penne', 'lasagne_vegetable_prepared', 'mandarine', 'kiwi',
         'french_beans', 'spring_roll_fried',
         'caprese_salad_tomato_mozzarella', 'leaf_spinach',
         'roll_of_half_white_or_white_flour_with_large_void',
         'omelette_with_flour_thick_crepe_plain', 'tuna', 'dark_chocolate',
         'sauce_savoury_n_s', 'raisins_dried',
         'ice_tea_on_black_tea_basis', 'kaki', 'smoothie',
         'crepe_with_flour_plain', 'nuggets', 'chili_con_carne_prepared',
         'veggie_burger', 'chinese_cabbage', 'hamburger', 'soup_pumpkin',
         'sushi', 'chestnuts_ch', 'sauce_soya', 'balsamic_salad_dressing',
         'pasta_twist', 'bolognaise_sauce', 'leek', 'fajita_bread_only',
         'potato_gnocchi', 'rice_noodles_vermicelli', 'bread_whole_wheat',
         'onion', 'garlic', 'hummus', 'pizza_with_vegetables_baked', 'beer',
         'glucose_drink_50g', 'ratatouille', 'peanut', 'cauliflower',
         'green_olives', 'bread_pita', 'pasta_wholemeal', 'sauce_pesto',
         'couscous', 'sauce', 'bread_toast', 'water_with_lemon_juice',
         'espresso', 'egg_scrambled', 'juice_orange', 'braided_white_loaf_ch',
         'emmental_cheese_ch',
         'hazelnut_chocolate_spread_nutella_ovomaltine_caotina', 'tomme_ch',
         'hazelnut', 'peach', 'figs',
         'mashed_potatoes_prepared_with_full_fat_milk_with_butter', 'pumpkin',
         'swiss_chard', 'red_cabbage_raw', 'spinach_raw',
         'chicken_curry_cream_coconut_milk_curry_spices_paste',
         'crunch_muesli', 'biscuit', 'meatloaf_ch', 'fresh_cheese_n_s',
         'honey', 'vegetable_mix_peas_and_carrots', 'parsley', 'brownie',
         'ice_cream_n_s', 'salad_dressing', 'dried_meat_n_s', 'chicken_breast',
         'mixed_salad_chopped_without_sauce', 'feta', 'praline_n_s', 'walnut',
         'potato_salad', 'kolhrabi', 'alfa_sprouts', 'brussel_sprouts',
         'gruyere_ch', 'bulgur', 'grapes', 'chocolate_egg_small', 'cappuccino',
         'crisp_bread', 'bread_black', 'rosti_n_s', 'mango', 'muesli_dry',
         'spinach', 'fish_n_s', 'risotto', 'crisps_ch', 'pork_n_s',
         'pomegranate', 'sweet_corn', 'flakes', 'greek_salad', 'sesame_seeds',
         'bouillon', 'baked_potato', 'fennel', 'meat_n_s', 'croutons',
         'bell_pepper_red_stewed', 'nuts', 'breadcrumbs_unspiced', 'fondue',
         'sauce_mushroom', 'strawberries', 'pie_plum_baked_with_cake_dough',
         'potatoes_au_gratin_dauphinois_prepared', 'capers',
         'bread_wholemeal_toast', 'red_radish', 'fruit_tart', 'beans_kidney',
         'sauerkraut', 'mustard', 'country_fries', 'ketchup',
         'pasta_linguini_parpadelle_tagliatelle',
         'chicken_cut_into_stripes_only_meat', 'cookies', 'sun_dried_tomatoe',
         'bread_ticino_ch', 'semi_hard_cheese',
         'porridge_prepared_with_partially_skimmed_milk', 'juice',
         'chocolate_milk', 'bread_fruit', 'corn', 'dates', 'pistachio',
         'cream_cheese_n_s', 'bread_rye', 'witloof_chicory',
         'goat_cheese_soft', 'grapefruit_pomelo', 'blue_mould_cheese',
         'guacamole', 'tofu', 'cordon_bleu', 'quinoa', 'kefir_drink',
         'salad_rocket', 'pizza_with_ham_with_mushrooms_baked', 'fruit_coulis',
         'plums', 'pizza_with_ham_baked', 'pineapple', 'seeds_n_s', 'focaccia',
         'mixed_milk_beverage', 'coleslaw_chopped_without_sauce',
         'sweet_potato', 'chicken_leg', 'croissant', 'cheesecake',
         'sauce_cocktail', 'croissant_with_chocolate_filling', 'pumpkin_seeds',
         'artichoke', 'soft_drink_with_a_taste', 'apple_pie',
         'white_bread_with_butter_eggs_and_milk', 'savoury_pastry_stick',
         'tuna_in_oil_drained', 'meat_terrine_pate', 'falafel_balls',
         'berries_n_s', 'latte_macchiato',
         'sugar_melon_galia_honeydew_cantaloupe', 'mixed_seeds_n_s',
         'oil_vinegar_salad_dressing', 'celeriac', 'chocolate_mousse', 'lemon',
         'chocolate_cookies', 'birchermuesli_prepared_no_sugar_added',
         'muffin', 'pine_nuts', 'french_pizza_from_alsace_baked',
         'chocolate_n_s', 'grits_polenta_maize_flour', 'wine_rose',
         'cola_based_drink', 'raspberries', 'roll_with_pieces_of_chocolate',
         'cake_lemon', 'rice_wild', 'gluten_free_bread', 'pearl_onion',
         'tzatziki', 'ham_croissant_ch', 'corn_crisps',
         'lentils_green_du_puy_du_berry', 'rice_whole_grain', 'cervelat_ch',
         'aperitif_with_alcohol_n_s_aperol_spritz', 'peas', 'tiramisu',
         'apricots', 'lasagne_meat_prepared', 'brioche',
         'vegetable_au_gratin_baked', 'basil', 'butter_spread_puree_almond',
         'pie_apricot', 'rusk_wholemeal', 'pasta_in_conch_form',
         'pasta_in_butterfly_form_farfalle', 'damson_plum', 'shoots_n_s',
         'coconut', 'banana_cake', 'sauce_curry', 'watermelon_fresh',
         'white_asparagus', 'cherries', 'nectarine')),
    val=dict(
        type='CocoDataset',
        ann_file=
        '/home/nick/segmentation/mmdetection/data/val/annotations_new.json',
        img_prefix='/home/nick/segmentation/mmdetection/data/val/images',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(
                type='MultiScaleFlipAug',
                img_scale=(1333, 800),
                flip=False,
                transforms=[
                    dict(type='Resize', keep_ratio=True),
                    dict(type='RandomFlip'),
                    dict(
                        type='Normalize',
                        mean=[123.675, 116.28, 103.53],
                        std=[58.395, 57.12, 57.375],
                        to_rgb=True),
                    dict(type='Pad', size_divisor=32),
                    dict(type='ImageToTensor', keys=['img']),
                    dict(type='Collect', keys=['img'])
                ])
        ],
        classes=
        ('beetroot-steamed-without-addition-of-salt', 'bread_wholemeal', 'jam',
         'water', 'bread', 'banana', 'soft_cheese', 'ham_raw', 'hard_cheese',
         'cottage_cheese', 'coffee', 'fruit_mixed', 'pancake', 'tea',
         'salmon_smoked', 'avocado', 'spring_onion_scallion',
         'ristretto_with_caffeine', 'ham_n_s', 'egg', 'bacon',
         'chips_french_fries', 'juice_apple', 'chicken', 'tomato', 'broccoli',
         'shrimp_prawn', 'carrot', 'chickpeas', 'french_salad_dressing',
         'pasta_hornli_ch', 'sauce_cream', 'pasta_n_s', 'tomato_sauce',
         'cheese_n_s', 'pear', 'cashew_nut', 'almonds', 'lentil_n_s',
         'mixed_vegetables', 'peanut_butter', 'apple', 'blueberries',
         'cucumber', 'yogurt', 'butter', 'mayonnaise', 'soup', 'wine_red',
         'wine_white', 'green_bean_steamed_without_addition_of_salt',
         'sausage', 'pizza_margherita_baked', 'salami_ch', 'mushroom',
         'tart_n_s', 'rice', 'white_coffee', 'sunflower_seeds',
         'bell_pepper_red_raw', 'zucchini', 'asparagus', 'tartar_sauce',
         'lye_pretzel_soft', 'cucumber_pickled_ch', 'curry_vegetarian',
         'soup_of_lentils_dahl_dhal', 'salmon',
         'salt_cake_ch_vegetables_filled', 'orange', 'pasta_noodles',
         'cream_double_cream_heavy_cream_45', 'cake_chocolate',
         'pasta_spaghetti', 'black_olives', 'parmesan', 'spaetzle',
         'salad_lambs_ear', 'salad_leaf_salad_green', 'potato',
         'white_cabbage', 'halloumi', 'beetroot_raw', 'bread_grain',
         'applesauce', 'cheese_for_raclette_ch', 'bread_white',
         'curds_natural', 'quiche', 'beef_n_s',
         'taboule_prepared_with_couscous', 'aubergine_eggplant', 'mozzarella',
         'pasta_penne', 'lasagne_vegetable_prepared', 'mandarine', 'kiwi',
         'french_beans', 'spring_roll_fried',
         'caprese_salad_tomato_mozzarella', 'leaf_spinach',
         'roll_of_half_white_or_white_flour_with_large_void',
         'omelette_with_flour_thick_crepe_plain', 'tuna', 'dark_chocolate',
         'sauce_savoury_n_s', 'raisins_dried',
         'ice_tea_on_black_tea_basis', 'kaki', 'smoothie',
         'crepe_with_flour_plain', 'nuggets', 'chili_con_carne_prepared',
         'veggie_burger', 'chinese_cabbage', 'hamburger', 'soup_pumpkin',
         'sushi', 'chestnuts_ch', 'sauce_soya', 'balsamic_salad_dressing',
         'pasta_twist', 'bolognaise_sauce', 'leek', 'fajita_bread_only',
         'potato_gnocchi', 'rice_noodles_vermicelli', 'bread_whole_wheat',
         'onion', 'garlic', 'hummus', 'pizza_with_vegetables_baked', 'beer',
         'glucose_drink_50g', 'ratatouille', 'peanut', 'cauliflower',
         'green_olives', 'bread_pita', 'pasta_wholemeal', 'sauce_pesto',
         'couscous', 'sauce', 'bread_toast', 'water_with_lemon_juice',
         'espresso', 'egg_scrambled', 'juice_orange', 'braided_white_loaf_ch',
         'emmental_cheese_ch',
         'hazelnut_chocolate_spread_nutella_ovomaltine_caotina', 'tomme_ch',
         'hazelnut', 'peach', 'figs',
         'mashed_potatoes_prepared_with_full_fat_milk_with_butter', 'pumpkin',
         'swiss_chard', 'red_cabbage_raw', 'spinach_raw',
         'chicken_curry_cream_coconut_milk_curry_spices_paste',
         'crunch_muesli', 'biscuit', 'meatloaf_ch', 'fresh_cheese_n_s',
         'honey', 'vegetable_mix_peas_and_carrots', 'parsley', 'brownie',
         'ice_cream_n_s', 'salad_dressing', 'dried_meat_n_s', 'chicken_breast',
         'mixed_salad_chopped_without_sauce', 'feta', 'praline_n_s', 'walnut',
         'potato_salad', 'kolhrabi', 'alfa_sprouts', 'brussel_sprouts',
         'gruyere_ch', 'bulgur', 'grapes', 'chocolate_egg_small', 'cappuccino',
         'crisp_bread', 'bread_black', 'rosti_n_s', 'mango', 'muesli_dry',
         'spinach', 'fish_n_s', 'risotto', 'crisps_ch', 'pork_n_s',
         'pomegranate', 'sweet_corn', 'flakes', 'greek_salad', 'sesame_seeds',
         'bouillon', 'baked_potato', 'fennel', 'meat_n_s', 'croutons',
         'bell_pepper_red_stewed', 'nuts', 'breadcrumbs_unspiced', 'fondue',
         'sauce_mushroom', 'strawberries', 'pie_plum_baked_with_cake_dough',
         'potatoes_au_gratin_dauphinois_prepared', 'capers',
         'bread_wholemeal_toast', 'red_radish', 'fruit_tart', 'beans_kidney',
         'sauerkraut', 'mustard', 'country_fries', 'ketchup',
         'pasta_linguini_parpadelle_tagliatelle',
         'chicken_cut_into_stripes_only_meat', 'cookies', 'sun_dried_tomatoe',
         'bread_ticino_ch', 'semi_hard_cheese',
         'porridge_prepared_with_partially_skimmed_milk', 'juice',
         'chocolate_milk', 'bread_fruit', 'corn', 'dates', 'pistachio',
         'cream_cheese_n_s', 'bread_rye', 'witloof_chicory',
         'goat_cheese_soft', 'grapefruit_pomelo', 'blue_mould_cheese',
         'guacamole', 'tofu', 'cordon_bleu', 'quinoa', 'kefir_drink',
         'salad_rocket', 'pizza_with_ham_with_mushrooms_baked', 'fruit_coulis',
         'plums', 'pizza_with_ham_baked', 'pineapple', 'seeds_n_s', 'focaccia',
         'mixed_milk_beverage', 'coleslaw_chopped_without_sauce',
         'sweet_potato', 'chicken_leg', 'croissant', 'cheesecake',
         'sauce_cocktail', 'croissant_with_chocolate_filling', 'pumpkin_seeds',
         'artichoke', 'soft_drink_with_a_taste', 'apple_pie',
         'white_bread_with_butter_eggs_and_milk', 'savoury_pastry_stick',
         'tuna_in_oil_drained', 'meat_terrine_pate', 'falafel_balls',
         'berries_n_s', 'latte_macchiato',
         'sugar_melon_galia_honeydew_cantaloupe', 'mixed_seeds_n_s',
         'oil_vinegar_salad_dressing', 'celeriac', 'chocolate_mousse', 'lemon',
         'chocolate_cookies', 'birchermuesli_prepared_no_sugar_added',
         'muffin', 'pine_nuts', 'french_pizza_from_alsace_baked',
         'chocolate_n_s', 'grits_polenta_maize_flour', 'wine_rose',
         'cola_based_drink', 'raspberries', 'roll_with_pieces_of_chocolate',
         'cake_lemon', 'rice_wild', 'gluten_free_bread', 'pearl_onion',
         'tzatziki', 'ham_croissant_ch', 'corn_crisps',
         'lentils_green_du_puy_du_berry', 'rice_whole_grain', 'cervelat_ch',
         'aperitif_with_alcohol_n_s_aperol_spritz', 'peas', 'tiramisu',
         'apricots', 'lasagne_meat_prepared', 'brioche',
         'vegetable_au_gratin_baked', 'basil', 'butter_spread_puree_almond',
         'pie_apricot', 'rusk_wholemeal', 'pasta_in_conch_form',
         'pasta_in_butterfly_form_farfalle', 'damson_plum', 'shoots_n_s',
         'coconut', 'banana_cake', 'sauce_curry', 'watermelon_fresh',
         'white_asparagus', 'cherries', 'nectarine')),
    test=dict(
        type='CocoDataset',
        ann_file=
        '/home/nick/segmentation/mmdetection/data/test/annotations.json',
        img_prefix='/home/nick/segmentation/mmdetection/data/test/images',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(
                type='MultiScaleFlipAug',
                img_scale=(1333, 800),
                flip=False,
                transforms=[
                    dict(type='Resize', keep_ratio=True),
                    dict(type='RandomFlip'),
                    dict(
                        type='Normalize',
                        mean=[123.675, 116.28, 103.53],
                        std=[58.395, 57.12, 57.375],
                        to_rgb=True),
                    dict(type='Pad', size_divisor=32),
                    dict(type='ImageToTensor', keys=['img']),
                    dict(type='Collect', keys=['img'])
                ])
        ],
        classes=
        ('beetroot-steamed-without-addition-of-salt', 'bread_wholemeal', 'jam',
         'water', 'bread', 'banana', 'soft_cheese', 'ham_raw', 'hard_cheese',
         'cottage_cheese', 'coffee', 'fruit_mixed', 'pancake', 'tea',
         'salmon_smoked', 'avocado', 'spring_onion_scallion',
         'ristretto_with_caffeine', 'ham_n_s', 'egg', 'bacon',
         'chips_french_fries', 'juice_apple', 'chicken', 'tomato', 'broccoli',
         'shrimp_prawn', 'carrot', 'chickpeas', 'french_salad_dressing',
         'pasta_hornli_ch', 'sauce_cream', 'pasta_n_s', 'tomato_sauce',
         'cheese_n_s', 'pear', 'cashew_nut', 'almonds', 'lentil_n_s',
         'mixed_vegetables', 'peanut_butter', 'apple', 'blueberries',
         'cucumber', 'yogurt', 'butter', 'mayonnaise', 'soup', 'wine_red',
         'wine_white', 'green_bean_steamed_without_addition_of_salt',
         'sausage', 'pizza_margherita_baked', 'salami_ch', 'mushroom',
         'tart_n_s', 'rice', 'white_coffee', 'sunflower_seeds',
         'bell_pepper_red_raw', 'zucchini', 'asparagus', 'tartar_sauce',
         'lye_pretzel_soft', 'cucumber_pickled_ch', 'curry_vegetarian',
         'soup_of_lentils_dahl_dhal', 'salmon',
         'salt_cake_ch_vegetables_filled', 'orange', 'pasta_noodles',
         'cream_double_cream_heavy_cream_45', 'cake_chocolate',
         'pasta_spaghetti', 'black_olives', 'parmesan', 'spaetzle',
         'salad_lambs_ear', 'salad_leaf_salad_green', 'potato',
         'white_cabbage', 'halloumi', 'beetroot_raw', 'bread_grain',
         'applesauce', 'cheese_for_raclette_ch', 'bread_white',
         'curds_natural', 'quiche', 'beef_n_s',
         'taboule_prepared_with_couscous', 'aubergine_eggplant', 'mozzarella',
         'pasta_penne', 'lasagne_vegetable_prepared', 'mandarine', 'kiwi',
         'french_beans', 'spring_roll_fried',
         'caprese_salad_tomato_mozzarella', 'leaf_spinach',
         'roll_of_half_white_or_white_flour_with_large_void',
         'omelette_with_flour_thick_crepe_plain', 'tuna', 'dark_chocolate',
         'sauce_savoury_n_s', 'raisins_dried',
         'ice_tea_on_black_tea_basis', 'kaki', 'smoothie',
         'crepe_with_flour_plain', 'nuggets', 'chili_con_carne_prepared',
         'veggie_burger', 'chinese_cabbage', 'hamburger', 'soup_pumpkin',
         'sushi', 'chestnuts_ch', 'sauce_soya', 'balsamic_salad_dressing',
         'pasta_twist', 'bolognaise_sauce', 'leek', 'fajita_bread_only',
         'potato_gnocchi', 'rice_noodles_vermicelli', 'bread_whole_wheat',
         'onion', 'garlic', 'hummus', 'pizza_with_vegetables_baked', 'beer',
         'glucose_drink_50g', 'ratatouille', 'peanut', 'cauliflower',
         'green_olives', 'bread_pita', 'pasta_wholemeal', 'sauce_pesto',
         'couscous', 'sauce', 'bread_toast', 'water_with_lemon_juice',
         'espresso', 'egg_scrambled', 'juice_orange', 'braided_white_loaf_ch',
         'emmental_cheese_ch',
         'hazelnut_chocolate_spread_nutella_ovomaltine_caotina', 'tomme_ch',
         'hazelnut', 'peach', 'figs',
         'mashed_potatoes_prepared_with_full_fat_milk_with_butter', 'pumpkin',
         'swiss_chard', 'red_cabbage_raw', 'spinach_raw',
         'chicken_curry_cream_coconut_milk_curry_spices_paste',
         'crunch_muesli', 'biscuit', 'meatloaf_ch', 'fresh_cheese_n_s',
         'honey', 'vegetable_mix_peas_and_carrots', 'parsley', 'brownie',
         'ice_cream_n_s', 'salad_dressing', 'dried_meat_n_s', 'chicken_breast',
         'mixed_salad_chopped_without_sauce', 'feta', 'praline_n_s', 'walnut',
         'potato_salad', 'kolhrabi', 'alfa_sprouts', 'brussel_sprouts',
         'gruyere_ch', 'bulgur', 'grapes', 'chocolate_egg_small', 'cappuccino',
         'crisp_bread', 'bread_black', 'rosti_n_s', 'mango', 'muesli_dry',
         'spinach', 'fish_n_s', 'risotto', 'crisps_ch', 'pork_n_s',
         'pomegranate', 'sweet_corn', 'flakes', 'greek_salad', 'sesame_seeds',
         'bouillon', 'baked_potato', 'fennel', 'meat_n_s', 'croutons',
         'bell_pepper_red_stewed', 'nuts', 'breadcrumbs_unspiced', 'fondue',
         'sauce_mushroom', 'strawberries', 'pie_plum_baked_with_cake_dough',
         'potatoes_au_gratin_dauphinois_prepared', 'capers',
         'bread_wholemeal_toast', 'red_radish', 'fruit_tart', 'beans_kidney',
         'sauerkraut', 'mustard', 'country_fries', 'ketchup',
         'pasta_linguini_parpadelle_tagliatelle',
         'chicken_cut_into_stripes_only_meat', 'cookies', 'sun_dried_tomatoe',
         'bread_ticino_ch', 'semi_hard_cheese',
         'porridge_prepared_with_partially_skimmed_milk', 'juice',
         'chocolate_milk', 'bread_fruit', 'corn', 'dates', 'pistachio',
         'cream_cheese_n_s', 'bread_rye', 'witloof_chicory',
         'goat_cheese_soft', 'grapefruit_pomelo', 'blue_mould_cheese',
         'guacamole', 'tofu', 'cordon_bleu', 'quinoa', 'kefir_drink',
         'salad_rocket', 'pizza_with_ham_with_mushrooms_baked', 'fruit_coulis',
         'plums', 'pizza_with_ham_baked', 'pineapple', 'seeds_n_s', 'focaccia',
         'mixed_milk_beverage', 'coleslaw_chopped_without_sauce',
         'sweet_potato', 'chicken_leg', 'croissant', 'cheesecake',
         'sauce_cocktail', 'croissant_with_chocolate_filling', 'pumpkin_seeds',
         'artichoke', 'soft_drink_with_a_taste', 'apple_pie',
         'white_bread_with_butter_eggs_and_milk', 'savoury_pastry_stick',
         'tuna_in_oil_drained', 'meat_terrine_pate', 'falafel_balls',
         'berries_n_s', 'latte_macchiato',
         'sugar_melon_galia_honeydew_cantaloupe', 'mixed_seeds_n_s',
         'oil_vinegar_salad_dressing', 'celeriac', 'chocolate_mousse', 'lemon',
         'chocolate_cookies', 'birchermuesli_prepared_no_sugar_added',
         'muffin', 'pine_nuts', 'french_pizza_from_alsace_baked',
         'chocolate_n_s', 'grits_polenta_maize_flour', 'wine_rose',
         'cola_based_drink', 'raspberries', 'roll_with_pieces_of_chocolate',
         'cake_lemon', 'rice_wild', 'gluten_free_bread', 'pearl_onion',
         'tzatziki', 'ham_croissant_ch', 'corn_crisps',
         'lentils_green_du_puy_du_berry', 'rice_whole_grain', 'cervelat_ch',
         'aperitif_with_alcohol_n_s_aperol_spritz', 'peas', 'tiramisu',
         'apricots', 'lasagne_meat_prepared', 'brioche',
         'vegetable_au_gratin_baked', 'basil', 'butter_spread_puree_almond',
         'pie_apricot', 'rusk_wholemeal', 'pasta_in_conch_form',
         'pasta_in_butterfly_form_farfalle', 'damson_plum', 'shoots_n_s',
         'coconut', 'banana_cake', 'sauce_curry', 'watermelon_fresh',
         'white_asparagus', 'cherries', 'nectarine')))
evaluation = dict(interval=1, metric=['segm'])
optimizer = dict(
    type='AdamW',
    lr=2e-05,
    weight_decay=0.0001,
    paramwise_cfg=dict(
        custom_keys=dict(
            absolute_pos_embed=dict(decay_mult=0.0),
            relative_position_bias_table=dict(decay_mult=0.0),
            norm=dict(decay_mult=0.0))))
optimizer_config = dict(
    grad_clip=dict(max_norm=1, norm_type=2),
    type='DistOptimizerHook',
    update_interval=1,
    coalesce=True,
    bucket_size_mb=-1,
    use_fp16=False)
lr_config = dict(
    policy='step',
    warmup='linear',
    warmup_iters=500,
    warmup_ratio=0.001,
    step=[14, 18])
runner = dict(type='EpochBasedRunner', max_epochs=20)
checkpoint_config = dict(interval=1)
log_config = dict(
    interval=1,
    hooks=[dict(type='TextLoggerHook'),
           dict(type='TensorboardLoggerHook')])
custom_hooks = [
    dict(type='NumClassCheckHook'),
    dict(type='EMAHook', interval=1, priority='HIGH')
]
dist_params = dict(backend='nccl')
log_level = 'INFO'
load_from = '/home/nick/segmentation/mmdetection/checkpoints/queryinst_swin_large_patch4_window7_fpn_300_queries-832c5813.pth'
resume_from = None
workflow = [('train', 1)]
num_stages = 6
num_proposals = 300
model = dict(
    type='QueryInst',
    pretrained=None,
    backbone=dict(
        type='SwinTransformer',
        embed_dim=192,
        depths=[2, 2, 18, 2],
        num_heads=[6, 12, 24, 48],
        window_size=7,
        mlp_ratio=4.0,
        qkv_bias=True,
        qk_scale=None,
        drop_rate=0.0,
        attn_drop_rate=0.0,
        drop_path_rate=0.3,
        ape=False,
        patch_norm=True,
        out_indices=(0, 1, 2, 3),
        use_checkpoint=False),
    neck=dict(
        type='FPN',
        in_channels=[192, 384, 768, 1536],
        out_channels=256,
        start_level=0,
        add_extra_convs='on_input',
        num_outs=4),
    rpn_head=dict(
        type='EmbeddingRPNHead',
        num_proposals=300,
        proposal_feature_channel=256),
    roi_head=dict(
        type='QueryRoIHead',
        num_stages=6,
        stage_loss_weights=[1, 1, 1, 1, 1, 1],
        proposal_feature_channel=256,
        bbox_roi_extractor=dict(
            type='SingleRoIExtractor',
            roi_layer=dict(type='RoIAlign', output_size=7, sampling_ratio=2),
            out_channels=256,
            featmap_strides=[4, 8, 16, 32]),
        mask_roi_extractor=dict(
            type='SingleRoIExtractor',
            roi_layer=dict(type='RoIAlign', output_size=14, sampling_ratio=2),
            out_channels=256,
            featmap_strides=[4, 8, 16, 32]),
        bbox_head=[
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0])),
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0])),
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0])),
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0])),
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0])),
            dict(
                type='DIIHead',
                num_classes=323,
                num_ffn_fcs=2,
                num_heads=8,
                num_cls_fcs=1,
                num_reg_fcs=3,
                feedforward_channels=2048,
                in_channels=256,
                dropout=0.0,
                ffn_act_cfg=dict(type='ReLU', inplace=True),
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=7,
                    with_proj=True,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                loss_bbox=dict(type='L1Loss', loss_weight=5.0),
                loss_iou=dict(type='GIoULoss', loss_weight=2.0),
                loss_cls=dict(
                    type='FocalLoss',
                    use_sigmoid=True,
                    gamma=2.0,
                    alpha=0.25,
                    loss_weight=2.0),
                bbox_coder=dict(
                    type='DeltaXYWHBBoxCoder',
                    clip_border=False,
                    target_means=[0.0, 0.0, 0.0, 0.0],
                    target_stds=[0.5, 0.5, 1.0, 1.0]))
        ],
        mask_head=[
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323),
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323),
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323),
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323),
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323),
            dict(
                type='DynamicMaskHead',
                dynamic_conv_cfg=dict(
                    type='DynamicConv',
                    in_channels=256,
                    feat_channels=64,
                    out_channels=256,
                    input_feat_shape=14,
                    with_proj=False,
                    act_cfg=dict(type='ReLU', inplace=True),
                    norm_cfg=dict(type='LN')),
                dropout=0.0,
                num_convs=4,
                roi_feat_size=14,
                in_channels=256,
                conv_kernel_size=3,
                conv_out_channels=256,
                class_agnostic=False,
                norm_cfg=dict(type='BN'),
                upsample_cfg=dict(type='deconv', scale_factor=2),
                loss_dice=dict(type='DiceLoss', loss_weight=8.0),
                num_classes=323)
        ]),
    train_cfg=dict(
        rpn=None,
        rcnn=[
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False),
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False),
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False),
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False),
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False),
            dict(
                assigner=dict(
                    type='HungarianAssigner',
                    cls_cost=dict(type='FocalLossCost', weight=2.0),
                    reg_cost=dict(type='BBoxL1Cost', weight=5.0),
                    iou_cost=dict(type='IoUCost', iou_mode='giou',
                                  weight=2.0)),
                sampler=dict(type='PseudoSampler'),
                pos_weight=1,
                mask_size=28,
                debug=False)
        ]),
    test_cfg=dict(rpn=None, rcnn=dict(max_per_img=300, mask_thr_binary=0.5, nms=dict(type='nms', iou_threshold=0.7))))
total_epochs = 20
min_values = (480, 512, 544, 576, 608, 640, 672, 704, 736, 768, 800)
fp16 = None
seed = 666
gpu_ids = [0]
classes = (
    'beetroot-steamed-without-addition-of-salt', 'bread_wholemeal', 'jam',
    'water', 'bread', 'banana', 'soft_cheese', 'ham_raw', 'hard_cheese',
    'cottage_cheese', 'coffee', 'fruit_mixed', 'pancake', 'tea',
    'salmon_smoked', 'avocado', 'spring_onion_scallion',
    'ristretto_with_caffeine', 'ham_n_s', 'egg', 'bacon', 'chips_french_fries',
    'juice_apple', 'chicken', 'tomato', 'broccoli', 'shrimp_prawn', 'carrot',
    'chickpeas', 'french_salad_dressing', 'pasta_hornli_ch', 'sauce_cream',
    'pasta_n_s', 'tomato_sauce', 'cheese_n_s', 'pear', 'cashew_nut', 'almonds',
    'lentil_n_s', 'mixed_vegetables', 'peanut_butter', 'apple', 'blueberries',
    'cucumber', 'yogurt', 'butter', 'mayonnaise', 'soup', 'wine_red',
    'wine_white', 'green_bean_steamed_without_addition_of_salt', 'sausage',
    'pizza_margherita_baked', 'salami_ch', 'mushroom', 'tart_n_s', 'rice',
    'white_coffee', 'sunflower_seeds', 'bell_pepper_red_raw', 'zucchini',
    'asparagus', 'tartar_sauce', 'lye_pretzel_soft', 'cucumber_pickled_ch',
    'curry_vegetarian', 'soup_of_lentils_dahl_dhal', 'salmon',
    'salt_cake_ch_vegetables_filled', 'orange', 'pasta_noodles',
    'cream_double_cream_heavy_cream_45', 'cake_chocolate', 'pasta_spaghetti',
    'black_olives', 'parmesan', 'spaetzle', 'salad_lambs_ear',
    'salad_leaf_salad_green', 'potato', 'white_cabbage', 'halloumi',
    'beetroot_raw', 'bread_grain', 'applesauce', 'cheese_for_raclette_ch',
    'bread_white', 'curds_natural', 'quiche', 'beef_n_s',
    'taboule_prepared_with_couscous', 'aubergine_eggplant', 'mozzarella',
    'pasta_penne', 'lasagne_vegetable_prepared', 'mandarine', 'kiwi',
    'french_beans', 'spring_roll_fried', 'caprese_salad_tomato_mozzarella',
    'leaf_spinach', 'roll_of_half_white_or_white_flour_with_large_void',
    'omelette_with_flour_thick_crepe_plain', 'tuna', 'dark_chocolate',
    'sauce_savoury_n_s', 'raisins_dried', 'ice_tea_on_black_tea_basis', 'kaki',
    'smoothie', 'crepe_with_flour_plain', 'nuggets',
    'chili_con_carne_prepared', 'veggie_burger', 'chinese_cabbage',
    'hamburger', 'soup_pumpkin', 'sushi', 'chestnuts_ch', 'sauce_soya',
    'balsamic_salad_dressing', 'pasta_twist', 'bolognaise_sauce', 'leek',
    'fajita_bread_only', 'potato_gnocchi', 'rice_noodles_vermicelli',
    'bread_whole_wheat', 'onion', 'garlic', 'hummus',
    'pizza_with_vegetables_baked', 'beer', 'glucose_drink_50g', 'ratatouille',
    'peanut', 'cauliflower', 'green_olives', 'bread_pita', 'pasta_wholemeal',
    'sauce_pesto', 'couscous', 'sauce', 'bread_toast',
    'water_with_lemon_juice', 'espresso', 'egg_scrambled', 'juice_orange',
    'braided_white_loaf_ch', 'emmental_cheese_ch',
    'hazelnut_chocolate_spread_nutella_ovomaltine_caotina', 'tomme_ch',
    'hazelnut', 'peach', 'figs',
    'mashed_potatoes_prepared_with_full_fat_milk_with_butter', 'pumpkin',
    'swiss_chard', 'red_cabbage_raw', 'spinach_raw',
    'chicken_curry_cream_coconut_milk_curry_spices_paste', 'crunch_muesli',
    'biscuit', 'meatloaf_ch', 'fresh_cheese_n_s', 'honey',
    'vegetable_mix_peas_and_carrots', 'parsley', 'brownie', 'ice_cream_n_s',
    'salad_dressing', 'dried_meat_n_s', 'chicken_breast',
    'mixed_salad_chopped_without_sauce', 'feta', 'praline_n_s', 'walnut',
    'potato_salad', 'kolhrabi', 'alfa_sprouts', 'brussel_sprouts',
    'gruyere_ch', 'bulgur', 'grapes', 'chocolate_egg_small', 'cappuccino',
    'crisp_bread', 'bread_black', 'rosti_n_s', 'mango', 'muesli_dry',
    'spinach', 'fish_n_s', 'risotto', 'crisps_ch', 'pork_n_s', 'pomegranate',
    'sweet_corn', 'flakes', 'greek_salad', 'sesame_seeds', 'bouillon',
    'baked_potato', 'fennel', 'meat_n_s', 'croutons', 'bell_pepper_red_stewed',
    'nuts', 'breadcrumbs_unspiced', 'fondue', 'sauce_mushroom', 'strawberries',
    'pie_plum_baked_with_cake_dough', 'potatoes_au_gratin_dauphinois_prepared',
    'capers', 'bread_wholemeal_toast', 'red_radish', 'fruit_tart',
    'beans_kidney', 'sauerkraut', 'mustard', 'country_fries', 'ketchup',
    'pasta_linguini_parpadelle_tagliatelle',
    'chicken_cut_into_stripes_only_meat', 'cookies', 'sun_dried_tomatoe',
    'bread_ticino_ch', 'semi_hard_cheese',
    'porridge_prepared_with_partially_skimmed_milk', 'juice', 'chocolate_milk',
    'bread_fruit', 'corn', 'dates', 'pistachio', 'cream_cheese_n_s',
    'bread_rye', 'witloof_chicory', 'goat_cheese_soft', 'grapefruit_pomelo',
    'blue_mould_cheese', 'guacamole', 'tofu', 'cordon_bleu', 'quinoa',
    'kefir_drink', 'salad_rocket', 'pizza_with_ham_with_mushrooms_baked',
    'fruit_coulis', 'plums', 'pizza_with_ham_baked', 'pineapple', 'seeds_n_s',
    'focaccia', 'mixed_milk_beverage', 'coleslaw_chopped_without_sauce',
    'sweet_potato', 'chicken_leg', 'croissant', 'cheesecake', 'sauce_cocktail',
    'croissant_with_chocolate_filling', 'pumpkin_seeds', 'artichoke',
    'soft_drink_with_a_taste', 'apple_pie',
    'white_bread_with_butter_eggs_and_milk', 'savoury_pastry_stick',
    'tuna_in_oil_drained', 'meat_terrine_pate', 'falafel_balls', 'berries_n_s',
    'latte_macchiato', 'sugar_melon_galia_honeydew_cantaloupe',
    'mixed_seeds_n_s', 'oil_vinegar_salad_dressing', 'celeriac',
    'chocolate_mousse', 'lemon', 'chocolate_cookies',
    'birchermuesli_prepared_no_sugar_added', 'muffin', 'pine_nuts',
    'french_pizza_from_alsace_baked', 'chocolate_n_s',
    'grits_polenta_maize_flour', 'wine_rose', 'cola_based_drink',
    'raspberries', 'roll_with_pieces_of_chocolate', 'cake_lemon', 'rice_wild',
    'gluten_free_bread', 'pearl_onion', 'tzatziki', 'ham_croissant_ch',
    'corn_crisps', 'lentils_green_du_puy_du_berry', 'rice_whole_grain',
    'cervelat_ch', 'aperitif_with_alcohol_n_s_aperol_spritz', 'peas',
    'tiramisu', 'apricots', 'lasagne_meat_prepared', 'brioche',
    'vegetable_au_gratin_baked', 'basil', 'butter_spread_puree_almond',
    'pie_apricot', 'rusk_wholemeal', 'pasta_in_conch_form',
    'pasta_in_butterfly_form_farfalle', 'damson_plum', 'shoots_n_s', 'coconut',
    'banana_cake', 'sauce_curry', 'watermelon_fresh', 'white_asparagus',
    'cherries', 'nectarine')
work_dir = './training_files/queryinst_20_2_2e-05_step_AdamW_2'
