dataset_type = 'CocoDataset'
data_root = 'data/coco/'
img_norm_cfg = dict(
    mean=[123.675, 116.28, 103.53], std=[58.395, 57.12, 57.375], to_rgb=True)
train_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(type='LoadAnnotations', with_bbox=True, with_mask=True),
    dict(
        type='Resize',
        img_scale=[(1333, 800), (1333, 768), (1333, 736), (1333, 704),
                   (1333, 672), (1333, 640)],
        multiscale_mode='value',
        keep_ratio=True),
    dict(type='RandomFlip', flip_ratio=0.5),
    dict(
        type='Normalize',
        mean=[123.675, 116.28, 103.53],
        std=[58.395, 57.12, 57.375],
        to_rgb=True),
    dict(type='Pad', size_divisor=32),
    dict(type='DefaultFormatBundle'),
    dict(type='Collect', keys=['img', 'gt_bboxes', 'gt_labels', 'gt_masks'])
]
test_pipeline = [
    dict(type='LoadImageFromFile'),
    dict(
        type='MultiScaleFlipAug',
        img_scale=(1333, 800),
        flip=False,
        transforms=[
            dict(type='Resize', keep_ratio=True),
            dict(type='RandomFlip'),
            dict(
                type='Normalize',
                mean=[123.675, 116.28, 103.53],
                std=[58.395, 57.12, 57.375],
                to_rgb=True),
            dict(type='Pad', size_divisor=32),
            dict(type='ImageToTensor', keys=['img']),
            dict(type='Collect', keys=['img'])
        ])
]
data = dict(
    samples_per_gpu=8,
    workers_per_gpu=1,
    train=dict(
        type='CocoDataset',
        ann_file='/home/nick/iggotsul/mmdetection/data/train/annotations.json',
        img_prefix='/home/nick/iggotsul/mmdetection/data/train/images',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(type='LoadAnnotations', with_bbox=True, with_mask=True),
            dict(
                type='Resize',
                img_scale=[(1333, 800), (1333, 768), (1333, 736), (1333, 704),
                           (1333, 672), (1333, 640)],
                multiscale_mode='value',
                keep_ratio=True),
            dict(type='RandomFlip', flip_ratio=0.5),
            dict(
                type='Normalize',
                mean=[123.675, 116.28, 103.53],
                std=[58.395, 57.12, 57.375],
                to_rgb=True),
            dict(type='Pad', size_divisor=32),
            dict(type='DefaultFormatBundle'),
            dict(
                type='Collect',
                keys=['img', 'gt_bboxes', 'gt_labels', 'gt_masks'])
        ],
        seg_prefix='/home/nick/iggotsul/mmdetection/data/train/images',
        classes=
        ('bread-wholemeal', 'jam', 'water', 'bread-sourdough', 'banana',
         'soft-cheese', 'ham-raw', 'hard-cheese', 'cottage-cheese',
         'bread-half-white', 'coffee-with-caffeine', 'fruit-salad', 'pancakes',
         'tea', 'salmon-smoked', 'avocado', 'spring-onion-scallion',
         'ristretto-with-caffeine', 'ham', 'egg', 'bacon-frying',
         'chips-french-fries', 'juice-apple', 'chicken', 'tomato-raw',
         'broccoli', 'shrimp-boiled',
         'beetroot-steamed-without-addition-of-salt', 'carrot-raw',
         'chickpeas', 'french-salad-dressing', 'pasta-hornli', 'sauce-cream',
         'meat-balls', 'pasta', 'tomato-sauce', 'cheese', 'pear', 'cashew-nut',
         'almonds', 'lentils', 'mixed-vegetables', 'peanut-butter', 'apple',
         'blueberries', 'cucumber', 'cocoa-powder',
         'greek-yaourt-yahourt-yogourt-ou-yoghourt', 'maple-syrup-concentrate',
         'buckwheat-grain-peeled', 'butter', 'herbal-tea', 'mayonnaise',
         'soup-vegetable', 'wine-red', 'wine-white',
         'green-bean-steamed-without-addition-of-salt', 'sausage',
         'pizza-margherita-baked', 'salami', 'mushroom',
         'bread-meat-substitute-lettuce-sauce', 'tart', 'tea-verveine', 'rice',
         'white-coffee-with-caffeine', 'linseeds', 'sunflower-seeds',
         'ham-cooked', 'bell-pepper-red-raw', 'zucchini', 'green-asparagus',
         'tartar-sauce', 'lye-pretzel-soft', 'cucumber-pickled',
         'curry-vegetarian', 'yaourt-yahourt-yogourt-ou-yoghourt-natural',
         'soup-of-lentils-dahl-dhal', 'soup-cream-of-vegetables',
         'balsamic-vinegar', 'salmon', 'salt-cake-vegetables-filled', 'bacon',
         'orange', 'pasta-noodles', 'cream', 'cake-chocolate',
         'pasta-spaghetti', 'black-olives', 'parmesan', 'spaetzle',
         'salad-lambs-ear', 'salad-leaf-salad-green', 'potatoes-steamed',
         'white-cabbage', 'halloumi', 'beetroot-raw', 'bread-grain',
         'applesauce-unsweetened-canned', 'cheese-for-raclette', 'mushrooms',
         'bread-white', 'curds-natural-with-at-most-10-fidm',
         'bagel-without-filling', 'quiche-with-cheese-baked-with-puff-pastry',
         'soup-potato', 'bouillon-vegetable', 'beef-sirloin-steak',
         'taboule-prepared-with-couscous', 'eggplant', 'bread',
         'turnover-with-meat-small-meat-pie-empanadas', 'mungbean-sprouts',
         'mozzarella', 'pasta-penne', 'lasagne-vegetable-prepared',
         'mandarine', 'kiwi', 'french-beans', 'tartar-meat',
         'spring-roll-fried', 'pork-chop', 'caprese-salad-tomato-mozzarella',
         'leaf-spinach', 'roll-of-half-white-or-white-flour-with-large-void',
         'pasta-ravioli-stuffing', 'omelette-plain', 'tuna', 'dark-chocolate',
         'sauce-savoury', 'dried-raisins', 'ice-tea', 'kaki', 'macaroon',
         'smoothie', 'crepe-plain', 'chicken-nuggets',
         'chili-con-carne-prepared', 'veggie-burger', 'cream-spinach', 'cod',
         'chinese-cabbage', 'hamburger-bread-meat-ketchup', 'soup-pumpkin',
         'sushi', 'chestnuts', 'coffee-decaffeinated', 'sauce-soya',
         'balsamic-salad-dressing', 'pasta-twist', 'bolognaise-sauce', 'leek',
         'fajita-bread-only', 'potato-gnocchi',
         'beef-cut-into-stripes-only-meat', 'rice-noodles-vermicelli',
         'tea-ginger', 'tea-green', 'bread-whole-wheat', 'onion', 'garlic',
         'hummus', 'pizza-with-vegetables-baked', 'beer', 'glucose-drink-50g',
         'chicken-wing', 'ratatouille', 'peanut',
         'high-protein-pasta-made-of-lentils-peas', 'cauliflower',
         'quiche-with-spinach-baked-with-cake-dough', 'green-olives',
         'brazil-nut', 'eggplant-caviar', 'bread-pita', 'pasta-wholemeal',
         'sauce-pesto', 'oil', 'couscous', 'sauce-roast', 'prosecco',
         'crackers', 'bread-toast', 'shrimp-prawn-small', 'panna-cotta',
         'romanesco', 'water-with-lemon-juice', 'espresso-with-caffeine',
         'egg-scrambled-prepared', 'juice-orange', 'ice-cubes',
         'braided-white-loaf', 'emmental-cheese', 'croissant-wholegrain',
         'hazelnut-chocolate-spread-nutella-ovomaltine-caotina', 'tomme',
         'water-mineral', 'hazelnut', 'bacon-raw', 'bread-nut',
         'black-forest-tart', 'soup-miso', 'peach', 'figs', 'beef-filet',
         'mustard-dijon', 'rice-basmati',
         'mashed-potatoes-prepared-with-full-fat-milk-with-butter',
         'dumplings', 'pumpkin', 'swiss-chard', 'red-cabbage', 'spinach-raw',
         'naan-indien-bread',
         'chicken-curry-cream-coconut-milk-curry-spices-paste',
         'crunch-muesli', 'biscuits', 'bread-french-white-flour', 'meatloaf',
         'fresh-cheese', 'honey', 'vegetable-mix-peas-and-carrots', 'parsley',
         'brownie', 'dairy-ice-cream', 'tea-black', 'carrot-cake',
         'fish-fingers-breaded', 'salad-dressing', 'dried-meat',
         'chicken-breast', 'mixed-salad-chopped-without-sauce', 'feta',
         'praline', 'tea-peppermint', 'walnut',
         'potato-salad-with-mayonnaise-yogurt-dressing', 'kebab-in-pita-bread',
         'kolhrabi', 'alfa-sprouts', 'brussel-sprouts', 'bacon-cooking',
         'gruyere', 'bulgur', 'grapes', 'pork-escalope', 'chocolate-egg-small',
         'cappuccino',
         'zucchini-stewed-without-addition-of-fat-without-addition-of-salt',
         'crisp-bread-wasa', 'bread-black', 'perch-fillets-lake', 'rosti',
         'mango', 'sandwich-ham-cheese-and-butter', 'muesli',
         'spinach-steamed-without-addition-of-salt', 'fish',
         'risotto-without-cheese-cooked', 'milk-chocolate-with-hazelnuts',
         'cake-oblong', 'crisps', 'pork', 'pomegranate', 'sweet-corn-canned',
         'flakes-oat', 'greek-salad', 'cantonese-fried-rice', 'sesame-seeds',
         'bouillon', 'baked-potato', 'fennel', 'meat', 'bread-olive',
         'croutons', 'philadelphia',
         'mushroom-average-stewed-without-addition-of-fat-without-addition-of-salt',
         'bell-pepper-red-stewed-without-addition-of-fat-without-addition-of-salt',
         'white-chocolate', 'mixed-nuts', 'breadcrumbs-unspiced', 'fondue',
         'sauce-mushroom', 'tea-spice', 'strawberries', 'tea-rooibos',
         'pie-plum-baked-with-cake-dough',
         'potatoes-au-gratin-dauphinois-prepared', 'capers', 'vegetables',
         'bread-wholemeal-toast', 'red-radish', 'fruit-tart', 'beans-kidney',
         'sauerkraut', 'mustard', 'country-fries', 'ketchup',
         'pasta-linguini-parpadelle-tagliatelle',
         'chicken-cut-into-stripes-only-meat', 'cookies', 'sun-dried-tomatoe',
         'bread-ticino', 'semi-hard-cheese', 'margarine',
         'porridge-prepared-with-partially-skimmed-milk',
         'soya-drink-soy-milk', 'juice-multifruit', 'popcorn-salted',
         'chocolate-filled', 'milk-chocolate', 'bread-fruit',
         'mix-of-dried-fruits-and-nuts', 'corn', 'tete-de-moine', 'dates',
         'pistachio', 'celery', 'white-radish', 'oat-milk', 'cream-cheese',
         'bread-rye', 'witloof-chicory', 'apple-crumble', 'goat-cheese-soft',
         'grapefruit-pomelo', 'risotto-with-mushrooms-cooked',
         'blue-mould-cheese', 'biscuit-with-butter', 'guacamole', 'pecan-nut',
         'tofu', 'cordon-bleu-from-pork-schnitzel-fried', 'paprika-chips',
         'quinoa', 'kefir-drink', 'm-m-s', 'salad-rocket', 'bread-spelt',
         'pizza-with-ham-with-mushrooms-baked', 'fruit-coulis', 'plums',
         'beef-minced-only-meat', 'pizza-with-ham-baked', 'pineapple',
         'soup-tomato', 'cheddar', 'tea-fruit', 'rice-jasmin', 'seeds',
         'focaccia', 'milk', 'coleslaw-chopped-without-sauce', 'pastry-flaky',
         'curd', 'savoury-puff-pastry-stick', 'sweet-potato', 'chicken-leg',
         'croissant', 'sour-cream', 'ham-turkey', 'processed-cheese',
         'fruit-compotes', 'cheesecake', 'pasta-tortelloni-stuffing',
         'sauce-cocktail', 'croissant-with-chocolate-filling', 'pumpkin-seeds',
         'artichoke', 'champagne', 'grissini', 'sweets-candies', 'brie',
         'wienerli-swiss-sausage', 'syrup-diluted-ready-to-drink', 'apple-pie',
         'white-bread-with-butter-eggs-and-milk', 'savoury-puff-pastry',
         'anchovies', 'tuna-in-oil-drained', 'lemon-pie', 'meat-terrine-pate',
         'coriander', 'falafel-balls', 'berries',
         'latte-macchiato-with-caffeine', 'faux-mage-cashew-vegan-chers',
         'beans-white', 'sugar-melon', 'mixed-seeds', 'hamburger',
         'hamburger-bun', 'oil-vinegar-salad-dressing',
         'soya-yaourt-yahourt-yogourt-ou-yoghourt',
         'chocolate-milk-chocolate-drink', 'celeriac', 'chocolate-mousse',
         'cenovis-yeast-spread', 'thickened-cream-35', 'meringue', 'lamb-chop',
         'shrimp-prawn-large', 'beef', 'lemon', 'croque-monsieur', 'chives',
         'chocolate-cookies', 'birchermuesli-prepared-no-sugar-added',
         'fish-crunchies-battered', 'muffin',
         'savoy-cabbage-steamed-without-addition-of-salt', 'pine-nuts',
         'chorizo', 'chia-grains', 'frying-sausage',
         'french-pizza-from-alsace-baked', 'chocolate', 'cooked-sausage',
         'grits-polenta-maize-flour',
         'gummi-bears-fruit-jellies-jelly-babies-with-fruit-essence',
         'wine-rose', 'coca-cola', 'raspberries',
         'roll-with-pieces-of-chocolate', 'goat-average-raw', 'lemon-cake',
         'coconut-milk', 'rice-wild', 'gluten-free-bread', 'pearl-onions',
         'buckwheat-pancake', 'bread-5-grain', 'light-beer', 'sugar-glazing',
         'tzatziki', 'butter-herb', 'ham-croissant', 'corn-crisps',
         'lentils-green-du-puy-du-berry', 'cocktail', 'rice-whole-grain',
         'veal-sausage', 'cervelat', 'sorbet',
         'aperitif-with-alcohol-aperol-spritz', 'dips', 'corn-flakes', 'peas',
         'tiramisu', 'apricots', 'cake-marble', 'lamb',
         'lasagne-meat-prepared', 'coca-cola-zero', 'cake-salted',
         'dough-puff-pastry-shortcrust-bread-pizza-dough', 'rice-waffels',
         'sekt', 'brioche', 'vegetable-au-gratin-baked', 'mango-dried',
         'processed-meat-charcuterie', 'mousse', 'sauce-sweet-sour', 'basil',
         'butter-spread-puree-almond', 'pie-apricot-baked-with-cake-dough',
         'rusk-wholemeal', 'beef-roast',
         'vanille-cream-cooked-custard-creme-dessert', 'pasta-in-conch-form',
         'nuts', 'sauce-carbonara', 'fig-dried',
         'pasta-in-butterfly-form-farfalle', 'minced-meat',
         'carrot-steamed-without-addition-of-salt', 'ebly', 'damson-plum',
         'shoots', 'bouquet-garni', 'coconut', 'banana-cake', 'waffle',
         'apricot-dried', 'sauce-curry', 'watermelon-fresh',
         'sauce-sweet-salted-asian', 'pork-roast', 'blackberry',
         'smoked-cooked-sausage-of-pork-and-beef-meat-sausag', 'bean-seeds',
         'italian-salad-dressing', 'white-asparagus',
         'pie-rhubarb-baked-with-cake-dough',
         'tomato-stewed-without-addition-of-fat-without-addition-of-salt',
         'cherries', 'nectarine')),
    val=dict(
        type='CocoDataset',
        ann_file='/home/nick/iggotsul/mmdetection/data/val/annotations.json',
        img_prefix='/home/nick/iggotsul/mmdetection/data/val/images',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(
                type='MultiScaleFlipAug',
                img_scale=(1333, 800),
                flip=False,
                transforms=[
                    dict(type='Resize', keep_ratio=True),
                    dict(type='RandomFlip'),
                    dict(
                        type='Normalize',
                        mean=[123.675, 116.28, 103.53],
                        std=[58.395, 57.12, 57.375],
                        to_rgb=True),
                    dict(type='Pad', size_divisor=32),
                    dict(type='ImageToTensor', keys=['img']),
                    dict(type='Collect', keys=['img'])
                ])
        ],
        classes=
        ('bread-wholemeal', 'jam', 'water', 'bread-sourdough', 'banana',
         'soft-cheese', 'ham-raw', 'hard-cheese', 'cottage-cheese',
         'bread-half-white', 'coffee-with-caffeine', 'fruit-salad', 'pancakes',
         'tea', 'salmon-smoked', 'avocado', 'spring-onion-scallion',
         'ristretto-with-caffeine', 'ham', 'egg', 'bacon-frying',
         'chips-french-fries', 'juice-apple', 'chicken', 'tomato-raw',
         'broccoli', 'shrimp-boiled',
         'beetroot-steamed-without-addition-of-salt', 'carrot-raw',
         'chickpeas', 'french-salad-dressing', 'pasta-hornli', 'sauce-cream',
         'meat-balls', 'pasta', 'tomato-sauce', 'cheese', 'pear', 'cashew-nut',
         'almonds', 'lentils', 'mixed-vegetables', 'peanut-butter', 'apple',
         'blueberries', 'cucumber', 'cocoa-powder',
         'greek-yaourt-yahourt-yogourt-ou-yoghourt', 'maple-syrup-concentrate',
         'buckwheat-grain-peeled', 'butter', 'herbal-tea', 'mayonnaise',
         'soup-vegetable', 'wine-red', 'wine-white',
         'green-bean-steamed-without-addition-of-salt', 'sausage',
         'pizza-margherita-baked', 'salami', 'mushroom',
         'bread-meat-substitute-lettuce-sauce', 'tart', 'tea-verveine', 'rice',
         'white-coffee-with-caffeine', 'linseeds', 'sunflower-seeds',
         'ham-cooked', 'bell-pepper-red-raw', 'zucchini', 'green-asparagus',
         'tartar-sauce', 'lye-pretzel-soft', 'cucumber-pickled',
         'curry-vegetarian', 'yaourt-yahourt-yogourt-ou-yoghourt-natural',
         'soup-of-lentils-dahl-dhal', 'soup-cream-of-vegetables',
         'balsamic-vinegar', 'salmon', 'salt-cake-vegetables-filled', 'bacon',
         'orange', 'pasta-noodles', 'cream', 'cake-chocolate',
         'pasta-spaghetti', 'black-olives', 'parmesan', 'spaetzle',
         'salad-lambs-ear', 'salad-leaf-salad-green', 'potatoes-steamed',
         'white-cabbage', 'halloumi', 'beetroot-raw', 'bread-grain',
         'applesauce-unsweetened-canned', 'cheese-for-raclette', 'mushrooms',
         'bread-white', 'curds-natural-with-at-most-10-fidm',
         'bagel-without-filling', 'quiche-with-cheese-baked-with-puff-pastry',
         'soup-potato', 'bouillon-vegetable', 'beef-sirloin-steak',
         'taboule-prepared-with-couscous', 'eggplant', 'bread',
         'turnover-with-meat-small-meat-pie-empanadas', 'mungbean-sprouts',
         'mozzarella', 'pasta-penne', 'lasagne-vegetable-prepared',
         'mandarine', 'kiwi', 'french-beans', 'tartar-meat',
         'spring-roll-fried', 'pork-chop', 'caprese-salad-tomato-mozzarella',
         'leaf-spinach', 'roll-of-half-white-or-white-flour-with-large-void',
         'pasta-ravioli-stuffing', 'omelette-plain', 'tuna', 'dark-chocolate',
         'sauce-savoury', 'dried-raisins', 'ice-tea', 'kaki', 'macaroon',
         'smoothie', 'crepe-plain', 'chicken-nuggets',
         'chili-con-carne-prepared', 'veggie-burger', 'cream-spinach', 'cod',
         'chinese-cabbage', 'hamburger-bread-meat-ketchup', 'soup-pumpkin',
         'sushi', 'chestnuts', 'coffee-decaffeinated', 'sauce-soya',
         'balsamic-salad-dressing', 'pasta-twist', 'bolognaise-sauce', 'leek',
         'fajita-bread-only', 'potato-gnocchi',
         'beef-cut-into-stripes-only-meat', 'rice-noodles-vermicelli',
         'tea-ginger', 'tea-green', 'bread-whole-wheat', 'onion', 'garlic',
         'hummus', 'pizza-with-vegetables-baked', 'beer', 'glucose-drink-50g',
         'chicken-wing', 'ratatouille', 'peanut',
         'high-protein-pasta-made-of-lentils-peas', 'cauliflower',
         'quiche-with-spinach-baked-with-cake-dough', 'green-olives',
         'brazil-nut', 'eggplant-caviar', 'bread-pita', 'pasta-wholemeal',
         'sauce-pesto', 'oil', 'couscous', 'sauce-roast', 'prosecco',
         'crackers', 'bread-toast', 'shrimp-prawn-small', 'panna-cotta',
         'romanesco', 'water-with-lemon-juice', 'espresso-with-caffeine',
         'egg-scrambled-prepared', 'juice-orange', 'ice-cubes',
         'braided-white-loaf', 'emmental-cheese', 'croissant-wholegrain',
         'hazelnut-chocolate-spread-nutella-ovomaltine-caotina', 'tomme',
         'water-mineral', 'hazelnut', 'bacon-raw', 'bread-nut',
         'black-forest-tart', 'soup-miso', 'peach', 'figs', 'beef-filet',
         'mustard-dijon', 'rice-basmati',
         'mashed-potatoes-prepared-with-full-fat-milk-with-butter',
         'dumplings', 'pumpkin', 'swiss-chard', 'red-cabbage', 'spinach-raw',
         'naan-indien-bread',
         'chicken-curry-cream-coconut-milk-curry-spices-paste',
         'crunch-muesli', 'biscuits', 'bread-french-white-flour', 'meatloaf',
         'fresh-cheese', 'honey', 'vegetable-mix-peas-and-carrots', 'parsley',
         'brownie', 'dairy-ice-cream', 'tea-black', 'carrot-cake',
         'fish-fingers-breaded', 'salad-dressing', 'dried-meat',
         'chicken-breast', 'mixed-salad-chopped-without-sauce', 'feta',
         'praline', 'tea-peppermint', 'walnut',
         'potato-salad-with-mayonnaise-yogurt-dressing', 'kebab-in-pita-bread',
         'kolhrabi', 'alfa-sprouts', 'brussel-sprouts', 'bacon-cooking',
         'gruyere', 'bulgur', 'grapes', 'pork-escalope', 'chocolate-egg-small',
         'cappuccino',
         'zucchini-stewed-without-addition-of-fat-without-addition-of-salt',
         'crisp-bread-wasa', 'bread-black', 'perch-fillets-lake', 'rosti',
         'mango', 'sandwich-ham-cheese-and-butter', 'muesli',
         'spinach-steamed-without-addition-of-salt', 'fish',
         'risotto-without-cheese-cooked', 'milk-chocolate-with-hazelnuts',
         'cake-oblong', 'crisps', 'pork', 'pomegranate', 'sweet-corn-canned',
         'flakes-oat', 'greek-salad', 'cantonese-fried-rice', 'sesame-seeds',
         'bouillon', 'baked-potato', 'fennel', 'meat', 'bread-olive',
         'croutons', 'philadelphia',
         'mushroom-average-stewed-without-addition-of-fat-without-addition-of-salt',
         'bell-pepper-red-stewed-without-addition-of-fat-without-addition-of-salt',
         'white-chocolate', 'mixed-nuts', 'breadcrumbs-unspiced', 'fondue',
         'sauce-mushroom', 'tea-spice', 'strawberries', 'tea-rooibos',
         'pie-plum-baked-with-cake-dough',
         'potatoes-au-gratin-dauphinois-prepared', 'capers', 'vegetables',
         'bread-wholemeal-toast', 'red-radish', 'fruit-tart', 'beans-kidney',
         'sauerkraut', 'mustard', 'country-fries', 'ketchup',
         'pasta-linguini-parpadelle-tagliatelle',
         'chicken-cut-into-stripes-only-meat', 'cookies', 'sun-dried-tomatoe',
         'bread-ticino', 'semi-hard-cheese', 'margarine',
         'porridge-prepared-with-partially-skimmed-milk',
         'soya-drink-soy-milk', 'juice-multifruit', 'popcorn-salted',
         'chocolate-filled', 'milk-chocolate', 'bread-fruit',
         'mix-of-dried-fruits-and-nuts', 'corn', 'tete-de-moine', 'dates',
         'pistachio', 'celery', 'white-radish', 'oat-milk', 'cream-cheese',
         'bread-rye', 'witloof-chicory', 'apple-crumble', 'goat-cheese-soft',
         'grapefruit-pomelo', 'risotto-with-mushrooms-cooked',
         'blue-mould-cheese', 'biscuit-with-butter', 'guacamole', 'pecan-nut',
         'tofu', 'cordon-bleu-from-pork-schnitzel-fried', 'paprika-chips',
         'quinoa', 'kefir-drink', 'm-m-s', 'salad-rocket', 'bread-spelt',
         'pizza-with-ham-with-mushrooms-baked', 'fruit-coulis', 'plums',
         'beef-minced-only-meat', 'pizza-with-ham-baked', 'pineapple',
         'soup-tomato', 'cheddar', 'tea-fruit', 'rice-jasmin', 'seeds',
         'focaccia', 'milk', 'coleslaw-chopped-without-sauce', 'pastry-flaky',
         'curd', 'savoury-puff-pastry-stick', 'sweet-potato', 'chicken-leg',
         'croissant', 'sour-cream', 'ham-turkey', 'processed-cheese',
         'fruit-compotes', 'cheesecake', 'pasta-tortelloni-stuffing',
         'sauce-cocktail', 'croissant-with-chocolate-filling', 'pumpkin-seeds',
         'artichoke', 'champagne', 'grissini', 'sweets-candies', 'brie',
         'wienerli-swiss-sausage', 'syrup-diluted-ready-to-drink', 'apple-pie',
         'white-bread-with-butter-eggs-and-milk', 'savoury-puff-pastry',
         'anchovies', 'tuna-in-oil-drained', 'lemon-pie', 'meat-terrine-pate',
         'coriander', 'falafel-balls', 'berries',
         'latte-macchiato-with-caffeine', 'faux-mage-cashew-vegan-chers',
         'beans-white', 'sugar-melon', 'mixed-seeds', 'hamburger',
         'hamburger-bun', 'oil-vinegar-salad-dressing',
         'soya-yaourt-yahourt-yogourt-ou-yoghourt',
         'chocolate-milk-chocolate-drink', 'celeriac', 'chocolate-mousse',
         'cenovis-yeast-spread', 'thickened-cream-35', 'meringue', 'lamb-chop',
         'shrimp-prawn-large', 'beef', 'lemon', 'croque-monsieur', 'chives',
         'chocolate-cookies', 'birchermuesli-prepared-no-sugar-added',
         'fish-crunchies-battered', 'muffin',
         'savoy-cabbage-steamed-without-addition-of-salt', 'pine-nuts',
         'chorizo', 'chia-grains', 'frying-sausage',
         'french-pizza-from-alsace-baked', 'chocolate', 'cooked-sausage',
         'grits-polenta-maize-flour',
         'gummi-bears-fruit-jellies-jelly-babies-with-fruit-essence',
         'wine-rose', 'coca-cola', 'raspberries',
         'roll-with-pieces-of-chocolate', 'goat-average-raw', 'lemon-cake',
         'coconut-milk', 'rice-wild', 'gluten-free-bread', 'pearl-onions',
         'buckwheat-pancake', 'bread-5-grain', 'light-beer', 'sugar-glazing',
         'tzatziki', 'butter-herb', 'ham-croissant', 'corn-crisps',
         'lentils-green-du-puy-du-berry', 'cocktail', 'rice-whole-grain',
         'veal-sausage', 'cervelat', 'sorbet',
         'aperitif-with-alcohol-aperol-spritz', 'dips', 'corn-flakes', 'peas',
         'tiramisu', 'apricots', 'cake-marble', 'lamb',
         'lasagne-meat-prepared', 'coca-cola-zero', 'cake-salted',
         'dough-puff-pastry-shortcrust-bread-pizza-dough', 'rice-waffels',
         'sekt', 'brioche', 'vegetable-au-gratin-baked', 'mango-dried',
         'processed-meat-charcuterie', 'mousse', 'sauce-sweet-sour', 'basil',
         'butter-spread-puree-almond', 'pie-apricot-baked-with-cake-dough',
         'rusk-wholemeal', 'beef-roast',
         'vanille-cream-cooked-custard-creme-dessert', 'pasta-in-conch-form',
         'nuts', 'sauce-carbonara', 'fig-dried',
         'pasta-in-butterfly-form-farfalle', 'minced-meat',
         'carrot-steamed-without-addition-of-salt', 'ebly', 'damson-plum',
         'shoots', 'bouquet-garni', 'coconut', 'banana-cake', 'waffle',
         'apricot-dried', 'sauce-curry', 'watermelon-fresh',
         'sauce-sweet-salted-asian', 'pork-roast', 'blackberry',
         'smoked-cooked-sausage-of-pork-and-beef-meat-sausag', 'bean-seeds',
         'italian-salad-dressing', 'white-asparagus',
         'pie-rhubarb-baked-with-cake-dough',
         'tomato-stewed-without-addition-of-fat-without-addition-of-salt',
         'cherries', 'nectarine')),
    test=dict(
        type='CocoDataset',
        ann_file='/home/nick/iggotsul/mmdetection/data/test/annotations.json',        
        img_prefix='/home/nick/iggotsul/mmdetection/data/test/images',
        pipeline=[
            dict(type='LoadImageFromFile'),
            dict(
                type='MultiScaleFlipAug',
                img_scale=(1333, 800),
                flip=False,
                transforms=[
                    dict(type='Resize', keep_ratio=True),
                    dict(type='RandomFlip'),
                    dict(
                        type='Normalize',
                        mean=[123.675, 116.28, 103.53],
                        std=[58.395, 57.12, 57.375],
                        to_rgb=True),
                    dict(type='Pad', size_divisor=32),
                    dict(type='ImageToTensor', keys=['img']),
                    dict(type='Collect', keys=['img'])
                ])
        ],
        classes=
        ('bread-wholemeal', 'jam', 'water', 'bread-sourdough', 'banana',
         'soft-cheese', 'ham-raw', 'hard-cheese', 'cottage-cheese',
         'bread-half-white', 'coffee-with-caffeine', 'fruit-salad', 'pancakes',
         'tea', 'salmon-smoked', 'avocado', 'spring-onion-scallion',
         'ristretto-with-caffeine', 'ham', 'egg', 'bacon-frying',
         'chips-french-fries', 'juice-apple', 'chicken', 'tomato-raw',
         'broccoli', 'shrimp-boiled',
         'beetroot-steamed-without-addition-of-salt', 'carrot-raw',
         'chickpeas', 'french-salad-dressing', 'pasta-hornli', 'sauce-cream',
         'meat-balls', 'pasta', 'tomato-sauce', 'cheese', 'pear', 'cashew-nut',
         'almonds', 'lentils', 'mixed-vegetables', 'peanut-butter', 'apple',
         'blueberries', 'cucumber', 'cocoa-powder',
         'greek-yaourt-yahourt-yogourt-ou-yoghourt', 'maple-syrup-concentrate',
         'buckwheat-grain-peeled', 'butter', 'herbal-tea', 'mayonnaise',
         'soup-vegetable', 'wine-red', 'wine-white',
         'green-bean-steamed-without-addition-of-salt', 'sausage',
         'pizza-margherita-baked', 'salami', 'mushroom',
         'bread-meat-substitute-lettuce-sauce', 'tart', 'tea-verveine', 'rice',
         'white-coffee-with-caffeine', 'linseeds', 'sunflower-seeds',
         'ham-cooked', 'bell-pepper-red-raw', 'zucchini', 'green-asparagus',
         'tartar-sauce', 'lye-pretzel-soft', 'cucumber-pickled',
         'curry-vegetarian', 'yaourt-yahourt-yogourt-ou-yoghourt-natural',
         'soup-of-lentils-dahl-dhal', 'soup-cream-of-vegetables',
         'balsamic-vinegar', 'salmon', 'salt-cake-vegetables-filled', 'bacon',
         'orange', 'pasta-noodles', 'cream', 'cake-chocolate',
         'pasta-spaghetti', 'black-olives', 'parmesan', 'spaetzle',
         'salad-lambs-ear', 'salad-leaf-salad-green', 'potatoes-steamed',
         'white-cabbage', 'halloumi', 'beetroot-raw', 'bread-grain',
         'applesauce-unsweetened-canned', 'cheese-for-raclette', 'mushrooms',
         'bread-white', 'curds-natural-with-at-most-10-fidm',
         'bagel-without-filling', 'quiche-with-cheese-baked-with-puff-pastry',
         'soup-potato', 'bouillon-vegetable', 'beef-sirloin-steak',
         'taboule-prepared-with-couscous', 'eggplant', 'bread',
         'turnover-with-meat-small-meat-pie-empanadas', 'mungbean-sprouts',
         'mozzarella', 'pasta-penne', 'lasagne-vegetable-prepared',
         'mandarine', 'kiwi', 'french-beans', 'tartar-meat',
         'spring-roll-fried', 'pork-chop', 'caprese-salad-tomato-mozzarella',
         'leaf-spinach', 'roll-of-half-white-or-white-flour-with-large-void',
         'pasta-ravioli-stuffing', 'omelette-plain', 'tuna', 'dark-chocolate',
         'sauce-savoury', 'dried-raisins', 'ice-tea', 'kaki', 'macaroon',
         'smoothie', 'crepe-plain', 'chicken-nuggets',
         'chili-con-carne-prepared', 'veggie-burger', 'cream-spinach', 'cod',
         'chinese-cabbage', 'hamburger-bread-meat-ketchup', 'soup-pumpkin',
         'sushi', 'chestnuts', 'coffee-decaffeinated', 'sauce-soya',
         'balsamic-salad-dressing', 'pasta-twist', 'bolognaise-sauce', 'leek',
         'fajita-bread-only', 'potato-gnocchi',
         'beef-cut-into-stripes-only-meat', 'rice-noodles-vermicelli',
         'tea-ginger', 'tea-green', 'bread-whole-wheat', 'onion', 'garlic',
         'hummus', 'pizza-with-vegetables-baked', 'beer', 'glucose-drink-50g',
         'chicken-wing', 'ratatouille', 'peanut',
         'high-protein-pasta-made-of-lentils-peas', 'cauliflower',
         'quiche-with-spinach-baked-with-cake-dough', 'green-olives',
         'brazil-nut', 'eggplant-caviar', 'bread-pita', 'pasta-wholemeal',
         'sauce-pesto', 'oil', 'couscous', 'sauce-roast', 'prosecco',
         'crackers', 'bread-toast', 'shrimp-prawn-small', 'panna-cotta',
         'romanesco', 'water-with-lemon-juice', 'espresso-with-caffeine',
         'egg-scrambled-prepared', 'juice-orange', 'ice-cubes',
         'braided-white-loaf', 'emmental-cheese', 'croissant-wholegrain',
         'hazelnut-chocolate-spread-nutella-ovomaltine-caotina', 'tomme',
         'water-mineral', 'hazelnut', 'bacon-raw', 'bread-nut',
         'black-forest-tart', 'soup-miso', 'peach', 'figs', 'beef-filet',
         'mustard-dijon', 'rice-basmati',
         'mashed-potatoes-prepared-with-full-fat-milk-with-butter',
         'dumplings', 'pumpkin', 'swiss-chard', 'red-cabbage', 'spinach-raw',
         'naan-indien-bread',
         'chicken-curry-cream-coconut-milk-curry-spices-paste',
         'crunch-muesli', 'biscuits', 'bread-french-white-flour', 'meatloaf',
         'fresh-cheese', 'honey', 'vegetable-mix-peas-and-carrots', 'parsley',
         'brownie', 'dairy-ice-cream', 'tea-black', 'carrot-cake',
         'fish-fingers-breaded', 'salad-dressing', 'dried-meat',
         'chicken-breast', 'mixed-salad-chopped-without-sauce', 'feta',
         'praline', 'tea-peppermint', 'walnut',
         'potato-salad-with-mayonnaise-yogurt-dressing', 'kebab-in-pita-bread',
         'kolhrabi', 'alfa-sprouts', 'brussel-sprouts', 'bacon-cooking',
         'gruyere', 'bulgur', 'grapes', 'pork-escalope', 'chocolate-egg-small',
         'cappuccino',
         'zucchini-stewed-without-addition-of-fat-without-addition-of-salt',
         'crisp-bread-wasa', 'bread-black', 'perch-fillets-lake', 'rosti',
         'mango', 'sandwich-ham-cheese-and-butter', 'muesli',
         'spinach-steamed-without-addition-of-salt', 'fish',
         'risotto-without-cheese-cooked', 'milk-chocolate-with-hazelnuts',
         'cake-oblong', 'crisps', 'pork', 'pomegranate', 'sweet-corn-canned',
         'flakes-oat', 'greek-salad', 'cantonese-fried-rice', 'sesame-seeds',
         'bouillon', 'baked-potato', 'fennel', 'meat', 'bread-olive',
         'croutons', 'philadelphia',
         'mushroom-average-stewed-without-addition-of-fat-without-addition-of-salt',
         'bell-pepper-red-stewed-without-addition-of-fat-without-addition-of-salt',
         'white-chocolate', 'mixed-nuts', 'breadcrumbs-unspiced', 'fondue',
         'sauce-mushroom', 'tea-spice', 'strawberries', 'tea-rooibos',
         'pie-plum-baked-with-cake-dough',
         'potatoes-au-gratin-dauphinois-prepared', 'capers', 'vegetables',
         'bread-wholemeal-toast', 'red-radish', 'fruit-tart', 'beans-kidney',
         'sauerkraut', 'mustard', 'country-fries', 'ketchup',
         'pasta-linguini-parpadelle-tagliatelle',
         'chicken-cut-into-stripes-only-meat', 'cookies', 'sun-dried-tomatoe',
         'bread-ticino', 'semi-hard-cheese', 'margarine',
         'porridge-prepared-with-partially-skimmed-milk',
         'soya-drink-soy-milk', 'juice-multifruit', 'popcorn-salted',
         'chocolate-filled', 'milk-chocolate', 'bread-fruit',
         'mix-of-dried-fruits-and-nuts', 'corn', 'tete-de-moine', 'dates',
         'pistachio', 'celery', 'white-radish', 'oat-milk', 'cream-cheese',
         'bread-rye', 'witloof-chicory', 'apple-crumble', 'goat-cheese-soft',
         'grapefruit-pomelo', 'risotto-with-mushrooms-cooked',
         'blue-mould-cheese', 'biscuit-with-butter', 'guacamole', 'pecan-nut',
         'tofu', 'cordon-bleu-from-pork-schnitzel-fried', 'paprika-chips',
         'quinoa', 'kefir-drink', 'm-m-s', 'salad-rocket', 'bread-spelt',
         'pizza-with-ham-with-mushrooms-baked', 'fruit-coulis', 'plums',
         'beef-minced-only-meat', 'pizza-with-ham-baked', 'pineapple',
         'soup-tomato', 'cheddar', 'tea-fruit', 'rice-jasmin', 'seeds',
         'focaccia', 'milk', 'coleslaw-chopped-without-sauce', 'pastry-flaky',
         'curd', 'savoury-puff-pastry-stick', 'sweet-potato', 'chicken-leg',
         'croissant', 'sour-cream', 'ham-turkey', 'processed-cheese',
         'fruit-compotes', 'cheesecake', 'pasta-tortelloni-stuffing',
         'sauce-cocktail', 'croissant-with-chocolate-filling', 'pumpkin-seeds',
         'artichoke', 'champagne', 'grissini', 'sweets-candies', 'brie',
         'wienerli-swiss-sausage', 'syrup-diluted-ready-to-drink', 'apple-pie',
         'white-bread-with-butter-eggs-and-milk', 'savoury-puff-pastry',
         'anchovies', 'tuna-in-oil-drained', 'lemon-pie', 'meat-terrine-pate',
         'coriander', 'falafel-balls', 'berries',
         'latte-macchiato-with-caffeine', 'faux-mage-cashew-vegan-chers',
         'beans-white', 'sugar-melon', 'mixed-seeds', 'hamburger',
         'hamburger-bun', 'oil-vinegar-salad-dressing',
         'soya-yaourt-yahourt-yogourt-ou-yoghourt',
         'chocolate-milk-chocolate-drink', 'celeriac', 'chocolate-mousse',
         'cenovis-yeast-spread', 'thickened-cream-35', 'meringue', 'lamb-chop',
         'shrimp-prawn-large', 'beef', 'lemon', 'croque-monsieur', 'chives',
         'chocolate-cookies', 'birchermuesli-prepared-no-sugar-added',
         'fish-crunchies-battered', 'muffin',
         'savoy-cabbage-steamed-without-addition-of-salt', 'pine-nuts',
         'chorizo', 'chia-grains', 'frying-sausage',
         'french-pizza-from-alsace-baked', 'chocolate', 'cooked-sausage',
         'grits-polenta-maize-flour',
         'gummi-bears-fruit-jellies-jelly-babies-with-fruit-essence',
         'wine-rose', 'coca-cola', 'raspberries',
         'roll-with-pieces-of-chocolate', 'goat-average-raw', 'lemon-cake',
         'coconut-milk', 'rice-wild', 'gluten-free-bread', 'pearl-onions',
         'buckwheat-pancake', 'bread-5-grain', 'light-beer', 'sugar-glazing',
         'tzatziki', 'butter-herb', 'ham-croissant', 'corn-crisps',
         'lentils-green-du-puy-du-berry', 'cocktail', 'rice-whole-grain',
         'veal-sausage', 'cervelat', 'sorbet',
         'aperitif-with-alcohol-aperol-spritz', 'dips', 'corn-flakes', 'peas',
         'tiramisu', 'apricots', 'cake-marble', 'lamb',
         'lasagne-meat-prepared', 'coca-cola-zero', 'cake-salted',
         'dough-puff-pastry-shortcrust-bread-pizza-dough', 'rice-waffels',
         'sekt', 'brioche', 'vegetable-au-gratin-baked', 'mango-dried',
         'processed-meat-charcuterie', 'mousse', 'sauce-sweet-sour', 'basil',
         'butter-spread-puree-almond', 'pie-apricot-baked-with-cake-dough',
         'rusk-wholemeal', 'beef-roast',
         'vanille-cream-cooked-custard-creme-dessert', 'pasta-in-conch-form',
         'nuts', 'sauce-carbonara', 'fig-dried',
         'pasta-in-butterfly-form-farfalle', 'minced-meat',
         'carrot-steamed-without-addition-of-salt', 'ebly', 'damson-plum',
         'shoots', 'bouquet-garni', 'coconut', 'banana-cake', 'waffle',
         'apricot-dried', 'sauce-curry', 'watermelon-fresh',
         'sauce-sweet-salted-asian', 'pork-roast', 'blackberry',
         'smoked-cooked-sausage-of-pork-and-beef-meat-sausag', 'bean-seeds',
         'italian-salad-dressing', 'white-asparagus',
         'pie-rhubarb-baked-with-cake-dough',
         'tomato-stewed-without-addition-of-fat-without-addition-of-salt',
         'cherries', 'nectarine')))
evaluation = dict(interval=1, metric=['segm'])
optimizer = dict(type='SGD', lr=0.001, momentum=0.9, weight_decay=0.0001)
optimizer_config = dict(grad_clip=None)
lr_config = dict(
    policy='CosineAnnealing',
    by_epoch=False,
    warmup='linear',
    warmup_iters=2000,
    warmup_ratio=0.001,
    min_lr=1e-07)
runner = dict(type='EpochBasedRunner', max_epochs=20)
checkpoint_config = dict(interval=1)
log_config = dict(
    interval=1,
    hooks=[dict(type='TextLoggerHook'),
           dict(type='TensorboardLoggerHook')])
custom_hooks = [dict(type='NumClassCheckHook')]
dist_params = dict(backend='nccl')
log_level = 'INFO'
load_from = '/home/nick/iggotsul/mmdetection/checkpoints/decoupled_solo_r50_fpn_3x_coco.pth'
resume_from = None
workflow = [('train', 1)]
model = dict(
    type='SOLO',
    backbone=dict(
        type='ResNet',
        depth=50,
        num_stages=4,
        out_indices=(0, 1, 2, 3),
        frozen_stages=1,
        init_cfg=dict(type='Pretrained', checkpoint='torchvision://resnet50'),
        style='pytorch'),
    neck=dict(
        type='FPN',
        in_channels=[256, 512, 1024, 2048],
        out_channels=256,
        start_level=0,
        num_outs=5),
    mask_head=dict(
        type='DecoupledSOLOHead',
        num_classes=498,
        in_channels=256,
        stacked_convs=7,
        feat_channels=256,
        strides=[8, 8, 16, 32, 32],
        scale_ranges=((1, 96), (48, 192), (96, 384), (192, 768), (384, 2048)),
        pos_scale=0.2,
        num_grids=[40, 36, 24, 16, 12],
        cls_down_index=0,
        loss_mask=dict(
            type='DiceLoss', use_sigmoid=True, loss_weight=3.0,
            activate=False),
        loss_cls=dict(
            type='FocalLoss',
            use_sigmoid=True,
            gamma=2.0,
            alpha=0.25,
            loss_weight=1.0),
        norm_cfg=dict(type='GN', num_groups=32, requires_grad=True)),
    test_cfg=dict(
        nms_pre=500,
        score_thr=0.1,
        mask_thr=0.5,
        filter_thr=0.05,
        kernel='gaussian',
        sigma=2.0,
        max_per_img=100))
work_dir = './training_files/solo'
seed = 666
total_epochs = 20
classes = (
    'bread-wholemeal', 'jam', 'water', 'bread-sourdough', 'banana',
    'soft-cheese', 'ham-raw', 'hard-cheese', 'cottage-cheese',
    'bread-half-white', 'coffee-with-caffeine', 'fruit-salad', 'pancakes',
    'tea', 'salmon-smoked', 'avocado', 'spring-onion-scallion',
    'ristretto-with-caffeine', 'ham', 'egg', 'bacon-frying',
    'chips-french-fries', 'juice-apple', 'chicken', 'tomato-raw', 'broccoli',
    'shrimp-boiled', 'beetroot-steamed-without-addition-of-salt', 'carrot-raw',
    'chickpeas', 'french-salad-dressing', 'pasta-hornli', 'sauce-cream',
    'meat-balls', 'pasta', 'tomato-sauce', 'cheese', 'pear', 'cashew-nut',
    'almonds', 'lentils', 'mixed-vegetables', 'peanut-butter', 'apple',
    'blueberries', 'cucumber', 'cocoa-powder',
    'greek-yaourt-yahourt-yogourt-ou-yoghourt', 'maple-syrup-concentrate',
    'buckwheat-grain-peeled', 'butter', 'herbal-tea', 'mayonnaise',
    'soup-vegetable', 'wine-red', 'wine-white',
    'green-bean-steamed-without-addition-of-salt', 'sausage',
    'pizza-margherita-baked', 'salami', 'mushroom',
    'bread-meat-substitute-lettuce-sauce', 'tart', 'tea-verveine', 'rice',
    'white-coffee-with-caffeine', 'linseeds', 'sunflower-seeds', 'ham-cooked',
    'bell-pepper-red-raw', 'zucchini', 'green-asparagus', 'tartar-sauce',
    'lye-pretzel-soft', 'cucumber-pickled', 'curry-vegetarian',
    'yaourt-yahourt-yogourt-ou-yoghourt-natural', 'soup-of-lentils-dahl-dhal',
    'soup-cream-of-vegetables', 'balsamic-vinegar', 'salmon',
    'salt-cake-vegetables-filled', 'bacon', 'orange', 'pasta-noodles', 'cream',
    'cake-chocolate', 'pasta-spaghetti', 'black-olives', 'parmesan',
    'spaetzle', 'salad-lambs-ear', 'salad-leaf-salad-green',
    'potatoes-steamed', 'white-cabbage', 'halloumi', 'beetroot-raw',
    'bread-grain', 'applesauce-unsweetened-canned', 'cheese-for-raclette',
    'mushrooms', 'bread-white', 'curds-natural-with-at-most-10-fidm',
    'bagel-without-filling', 'quiche-with-cheese-baked-with-puff-pastry',
    'soup-potato', 'bouillon-vegetable', 'beef-sirloin-steak',
    'taboule-prepared-with-couscous', 'eggplant', 'bread',
    'turnover-with-meat-small-meat-pie-empanadas', 'mungbean-sprouts',
    'mozzarella', 'pasta-penne', 'lasagne-vegetable-prepared', 'mandarine',
    'kiwi', 'french-beans', 'tartar-meat', 'spring-roll-fried', 'pork-chop',
    'caprese-salad-tomato-mozzarella', 'leaf-spinach',
    'roll-of-half-white-or-white-flour-with-large-void',
    'pasta-ravioli-stuffing', 'omelette-plain', 'tuna', 'dark-chocolate',
    'sauce-savoury', 'dried-raisins', 'ice-tea', 'kaki', 'macaroon',
    'smoothie', 'crepe-plain', 'chicken-nuggets', 'chili-con-carne-prepared',
    'veggie-burger', 'cream-spinach', 'cod', 'chinese-cabbage',
    'hamburger-bread-meat-ketchup', 'soup-pumpkin', 'sushi', 'chestnuts',
    'coffee-decaffeinated', 'sauce-soya', 'balsamic-salad-dressing',
    'pasta-twist', 'bolognaise-sauce', 'leek', 'fajita-bread-only',
    'potato-gnocchi', 'beef-cut-into-stripes-only-meat',
    'rice-noodles-vermicelli', 'tea-ginger', 'tea-green', 'bread-whole-wheat',
    'onion', 'garlic', 'hummus', 'pizza-with-vegetables-baked', 'beer',
    'glucose-drink-50g', 'chicken-wing', 'ratatouille', 'peanut',
    'high-protein-pasta-made-of-lentils-peas', 'cauliflower',
    'quiche-with-spinach-baked-with-cake-dough', 'green-olives', 'brazil-nut',
    'eggplant-caviar', 'bread-pita', 'pasta-wholemeal', 'sauce-pesto', 'oil',
    'couscous', 'sauce-roast', 'prosecco', 'crackers', 'bread-toast',
    'shrimp-prawn-small', 'panna-cotta', 'romanesco', 'water-with-lemon-juice',
    'espresso-with-caffeine', 'egg-scrambled-prepared', 'juice-orange',
    'ice-cubes', 'braided-white-loaf', 'emmental-cheese',
    'croissant-wholegrain',
    'hazelnut-chocolate-spread-nutella-ovomaltine-caotina', 'tomme',
    'water-mineral', 'hazelnut', 'bacon-raw', 'bread-nut', 'black-forest-tart',
    'soup-miso', 'peach', 'figs', 'beef-filet', 'mustard-dijon',
    'rice-basmati', 'mashed-potatoes-prepared-with-full-fat-milk-with-butter',
    'dumplings', 'pumpkin', 'swiss-chard', 'red-cabbage', 'spinach-raw',
    'naan-indien-bread', 'chicken-curry-cream-coconut-milk-curry-spices-paste',
    'crunch-muesli', 'biscuits', 'bread-french-white-flour', 'meatloaf',
    'fresh-cheese', 'honey', 'vegetable-mix-peas-and-carrots', 'parsley',
    'brownie', 'dairy-ice-cream', 'tea-black', 'carrot-cake',
    'fish-fingers-breaded', 'salad-dressing', 'dried-meat', 'chicken-breast',
    'mixed-salad-chopped-without-sauce', 'feta', 'praline', 'tea-peppermint',
    'walnut', 'potato-salad-with-mayonnaise-yogurt-dressing',
    'kebab-in-pita-bread', 'kolhrabi', 'alfa-sprouts', 'brussel-sprouts',
    'bacon-cooking', 'gruyere', 'bulgur', 'grapes', 'pork-escalope',
    'chocolate-egg-small', 'cappuccino',
    'zucchini-stewed-without-addition-of-fat-without-addition-of-salt',
    'crisp-bread-wasa', 'bread-black', 'perch-fillets-lake', 'rosti', 'mango',
    'sandwich-ham-cheese-and-butter', 'muesli',
    'spinach-steamed-without-addition-of-salt', 'fish',
    'risotto-without-cheese-cooked', 'milk-chocolate-with-hazelnuts',
    'cake-oblong', 'crisps', 'pork', 'pomegranate', 'sweet-corn-canned',
    'flakes-oat', 'greek-salad', 'cantonese-fried-rice', 'sesame-seeds',
    'bouillon', 'baked-potato', 'fennel', 'meat', 'bread-olive', 'croutons',
    'philadelphia',
    'mushroom-average-stewed-without-addition-of-fat-without-addition-of-salt',
    'bell-pepper-red-stewed-without-addition-of-fat-without-addition-of-salt',
    'white-chocolate', 'mixed-nuts', 'breadcrumbs-unspiced', 'fondue',
    'sauce-mushroom', 'tea-spice', 'strawberries', 'tea-rooibos',
    'pie-plum-baked-with-cake-dough', 'potatoes-au-gratin-dauphinois-prepared',
    'capers', 'vegetables', 'bread-wholemeal-toast', 'red-radish',
    'fruit-tart', 'beans-kidney', 'sauerkraut', 'mustard', 'country-fries',
    'ketchup', 'pasta-linguini-parpadelle-tagliatelle',
    'chicken-cut-into-stripes-only-meat', 'cookies', 'sun-dried-tomatoe',
    'bread-ticino', 'semi-hard-cheese', 'margarine',
    'porridge-prepared-with-partially-skimmed-milk', 'soya-drink-soy-milk',
    'juice-multifruit', 'popcorn-salted', 'chocolate-filled', 'milk-chocolate',
    'bread-fruit', 'mix-of-dried-fruits-and-nuts', 'corn', 'tete-de-moine',
    'dates', 'pistachio', 'celery', 'white-radish', 'oat-milk', 'cream-cheese',
    'bread-rye', 'witloof-chicory', 'apple-crumble', 'goat-cheese-soft',
    'grapefruit-pomelo', 'risotto-with-mushrooms-cooked', 'blue-mould-cheese',
    'biscuit-with-butter', 'guacamole', 'pecan-nut', 'tofu',
    'cordon-bleu-from-pork-schnitzel-fried', 'paprika-chips', 'quinoa',
    'kefir-drink', 'm-m-s', 'salad-rocket', 'bread-spelt',
    'pizza-with-ham-with-mushrooms-baked', 'fruit-coulis', 'plums',
    'beef-minced-only-meat', 'pizza-with-ham-baked', 'pineapple',
    'soup-tomato', 'cheddar', 'tea-fruit', 'rice-jasmin', 'seeds', 'focaccia',
    'milk', 'coleslaw-chopped-without-sauce', 'pastry-flaky', 'curd',
    'savoury-puff-pastry-stick', 'sweet-potato', 'chicken-leg', 'croissant',
    'sour-cream', 'ham-turkey', 'processed-cheese', 'fruit-compotes',
    'cheesecake', 'pasta-tortelloni-stuffing', 'sauce-cocktail',
    'croissant-with-chocolate-filling', 'pumpkin-seeds', 'artichoke',
    'champagne', 'grissini', 'sweets-candies', 'brie',
    'wienerli-swiss-sausage', 'syrup-diluted-ready-to-drink', 'apple-pie',
    'white-bread-with-butter-eggs-and-milk', 'savoury-puff-pastry',
    'anchovies', 'tuna-in-oil-drained', 'lemon-pie', 'meat-terrine-pate',
    'coriander', 'falafel-balls', 'berries', 'latte-macchiato-with-caffeine',
    'faux-mage-cashew-vegan-chers', 'beans-white', 'sugar-melon',
    'mixed-seeds', 'hamburger', 'hamburger-bun', 'oil-vinegar-salad-dressing',
    'soya-yaourt-yahourt-yogourt-ou-yoghourt',
    'chocolate-milk-chocolate-drink', 'celeriac', 'chocolate-mousse',
    'cenovis-yeast-spread', 'thickened-cream-35', 'meringue', 'lamb-chop',
    'shrimp-prawn-large', 'beef', 'lemon', 'croque-monsieur', 'chives',
    'chocolate-cookies', 'birchermuesli-prepared-no-sugar-added',
    'fish-crunchies-battered', 'muffin',
    'savoy-cabbage-steamed-without-addition-of-salt', 'pine-nuts', 'chorizo',
    'chia-grains', 'frying-sausage', 'french-pizza-from-alsace-baked',
    'chocolate', 'cooked-sausage', 'grits-polenta-maize-flour',
    'gummi-bears-fruit-jellies-jelly-babies-with-fruit-essence', 'wine-rose',
    'coca-cola', 'raspberries', 'roll-with-pieces-of-chocolate',
    'goat-average-raw', 'lemon-cake', 'coconut-milk', 'rice-wild',
    'gluten-free-bread', 'pearl-onions', 'buckwheat-pancake', 'bread-5-grain',
    'light-beer', 'sugar-glazing', 'tzatziki', 'butter-herb', 'ham-croissant',
    'corn-crisps', 'lentils-green-du-puy-du-berry', 'cocktail',
    'rice-whole-grain', 'veal-sausage', 'cervelat', 'sorbet',
    'aperitif-with-alcohol-aperol-spritz', 'dips', 'corn-flakes', 'peas',
    'tiramisu', 'apricots', 'cake-marble', 'lamb', 'lasagne-meat-prepared',
    'coca-cola-zero', 'cake-salted',
    'dough-puff-pastry-shortcrust-bread-pizza-dough', 'rice-waffels', 'sekt',
    'brioche', 'vegetable-au-gratin-baked', 'mango-dried',
    'processed-meat-charcuterie', 'mousse', 'sauce-sweet-sour', 'basil',
    'butter-spread-puree-almond', 'pie-apricot-baked-with-cake-dough',
    'rusk-wholemeal', 'beef-roast',
    'vanille-cream-cooked-custard-creme-dessert', 'pasta-in-conch-form',
    'nuts', 'sauce-carbonara', 'fig-dried', 'pasta-in-butterfly-form-farfalle',
    'minced-meat', 'carrot-steamed-without-addition-of-salt', 'ebly',
    'damson-plum', 'shoots', 'bouquet-garni', 'coconut', 'banana-cake',
    'waffle', 'apricot-dried', 'sauce-curry', 'watermelon-fresh',
    'sauce-sweet-salted-asian', 'pork-roast', 'blackberry',
    'smoked-cooked-sausage-of-pork-and-beef-meat-sausag', 'bean-seeds',
    'italian-salad-dressing', 'white-asparagus',
    'pie-rhubarb-baked-with-cake-dough',
    'tomato-stewed-without-addition-of-fat-without-addition-of-salt',
    'cherries', 'nectarine')
gpu_ids = [0]
